# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ReadBarcodeAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'barcode_types': 'list[str]',
        'barcode_orientation': 'list[str]',
        'barcodes_to_read': 'int',
        'scan_interval': 'int',
        'quiet_zone_size': 'str',
        'pdf_reading_type': 'str',
        'pdf_render_dpi': 'int',
        'threshold_mode': 'str',
        'threshold_count': 'int',
        'threshold_step': 'int',
        'scan_page': 'int',
        'i2of5_checksum': 'bool',
        'code11_checksum': 'bool',
        'code39_checksum': 'bool',
        'code93_checksum': 'bool',
        'image_despeckle': 'int',
        'image_erode': 'int',
        'image_dilate': 'int',
        'image_sharp': 'int',
        'image_invert': 'int'
    }

    attribute_map = {
        'barcode_types': 'barcodeTypes',
        'barcode_orientation': 'barcodeOrientation',
        'barcodes_to_read': 'barcodesToRead',
        'scan_interval': 'scanInterval',
        'quiet_zone_size': 'quietZoneSize',
        'pdf_reading_type': 'pdfReadingType',
        'pdf_render_dpi': 'pdfRenderDPI',
        'threshold_mode': 'thresholdMode',
        'threshold_count': 'thresholdCount',
        'threshold_step': 'thresholdStep',
        'scan_page': 'scanPage',
        'i2of5_checksum': 'i2of5Checksum',
        'code11_checksum': 'code11Checksum',
        'code39_checksum': 'code39Checksum',
        'code93_checksum': 'code93Checksum',
        'image_despeckle': 'imageDespeckle',
        'image_erode': 'imageErode',
        'image_dilate': 'imageDilate',
        'image_sharp': 'imageSharp',
        'image_invert': 'imageInvert'
    }

    def __init__(self, barcode_types=None, barcode_orientation=None, barcodes_to_read=None, scan_interval=None, quiet_zone_size=None, pdf_reading_type=None, pdf_render_dpi=None, threshold_mode=None, threshold_count=None, threshold_step=None, scan_page=None, i2of5_checksum=None, code11_checksum=None, code39_checksum=None, code93_checksum=None, image_despeckle=None, image_erode=None, image_dilate=None, image_sharp=None, image_invert=None):  # noqa: E501
        """ReadBarcodeAction - a model defined in Swagger"""  # noqa: E501

        self._barcode_types = None
        self._barcode_orientation = None
        self._barcodes_to_read = None
        self._scan_interval = None
        self._quiet_zone_size = None
        self._pdf_reading_type = None
        self._pdf_render_dpi = None
        self._threshold_mode = None
        self._threshold_count = None
        self._threshold_step = None
        self._scan_page = None
        self._i2of5_checksum = None
        self._code11_checksum = None
        self._code39_checksum = None
        self._code93_checksum = None
        self._image_despeckle = None
        self._image_erode = None
        self._image_dilate = None
        self._image_sharp = None
        self._image_invert = None
        self.discriminator = None

        if barcode_types is not None:
            self.barcode_types = barcode_types
        if barcode_orientation is not None:
            self.barcode_orientation = barcode_orientation
        if barcodes_to_read is not None:
            self.barcodes_to_read = barcodes_to_read
        if scan_interval is not None:
            self.scan_interval = scan_interval
        if quiet_zone_size is not None:
            self.quiet_zone_size = quiet_zone_size
        if pdf_reading_type is not None:
            self.pdf_reading_type = pdf_reading_type
        if pdf_render_dpi is not None:
            self.pdf_render_dpi = pdf_render_dpi
        if threshold_mode is not None:
            self.threshold_mode = threshold_mode
        if threshold_count is not None:
            self.threshold_count = threshold_count
        if threshold_step is not None:
            self.threshold_step = threshold_step
        if scan_page is not None:
            self.scan_page = scan_page
        if i2of5_checksum is not None:
            self.i2of5_checksum = i2of5_checksum
        if code11_checksum is not None:
            self.code11_checksum = code11_checksum
        if code39_checksum is not None:
            self.code39_checksum = code39_checksum
        if code93_checksum is not None:
            self.code93_checksum = code93_checksum
        if image_despeckle is not None:
            self.image_despeckle = image_despeckle
        if image_erode is not None:
            self.image_erode = image_erode
        if image_dilate is not None:
            self.image_dilate = image_dilate
        if image_sharp is not None:
            self.image_sharp = image_sharp
        if image_invert is not None:
            self.image_invert = image_invert

    @property
    def barcode_types(self):
        """Gets the barcode_types of this ReadBarcodeAction.  # noqa: E501


        :return: The barcode_types of this ReadBarcodeAction.  # noqa: E501
        :rtype: list[str]
        """
        return self._barcode_types

    @barcode_types.setter
    def barcode_types(self, barcode_types):
        """Sets the barcode_types of this ReadBarcodeAction.


        :param barcode_types: The barcode_types of this ReadBarcodeAction.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["all", "unknown", "code11", "code39", "code93", "code128", "codabar", "inter2of5", "patchCode", "ean8", "upce", "ean13", "upca", "plus2", "plus5", "pdf417", "dataMatrix", "qrCode", "postnet", "planet", "rm4SCC", "australiaPost", "intelligentMail", "code39Extended", "microQRCode", "all_2D", "pharmaCode", "ucc128", "rss14", "rssLimited", "rssExpanded", "all_1D"]  # noqa: E501
        if not set(barcode_types).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `barcode_types` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(barcode_types) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._barcode_types = barcode_types

    @property
    def barcode_orientation(self):
        """Gets the barcode_orientation of this ReadBarcodeAction.  # noqa: E501


        :return: The barcode_orientation of this ReadBarcodeAction.  # noqa: E501
        :rtype: list[str]
        """
        return self._barcode_orientation

    @barcode_orientation.setter
    def barcode_orientation(self, barcode_orientation):
        """Sets the barcode_orientation of this ReadBarcodeAction.


        :param barcode_orientation: The barcode_orientation of this ReadBarcodeAction.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["unknown", "leftToRight", "rightToLeft", "topToBottom", "bottomToTop", "all"]  # noqa: E501
        if not set(barcode_orientation).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `barcode_orientation` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(barcode_orientation) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._barcode_orientation = barcode_orientation

    @property
    def barcodes_to_read(self):
        """Gets the barcodes_to_read of this ReadBarcodeAction.  # noqa: E501


        :return: The barcodes_to_read of this ReadBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._barcodes_to_read

    @barcodes_to_read.setter
    def barcodes_to_read(self, barcodes_to_read):
        """Sets the barcodes_to_read of this ReadBarcodeAction.


        :param barcodes_to_read: The barcodes_to_read of this ReadBarcodeAction.  # noqa: E501
        :type: int
        """

        self._barcodes_to_read = barcodes_to_read

    @property
    def scan_interval(self):
        """Gets the scan_interval of this ReadBarcodeAction.  # noqa: E501


        :return: The scan_interval of this ReadBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._scan_interval

    @scan_interval.setter
    def scan_interval(self, scan_interval):
        """Sets the scan_interval of this ReadBarcodeAction.


        :param scan_interval: The scan_interval of this ReadBarcodeAction.  # noqa: E501
        :type: int
        """

        self._scan_interval = scan_interval

    @property
    def quiet_zone_size(self):
        """Gets the quiet_zone_size of this ReadBarcodeAction.  # noqa: E501


        :return: The quiet_zone_size of this ReadBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._quiet_zone_size

    @quiet_zone_size.setter
    def quiet_zone_size(self, quiet_zone_size):
        """Sets the quiet_zone_size of this ReadBarcodeAction.


        :param quiet_zone_size: The quiet_zone_size of this ReadBarcodeAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["extraSmall", "small", "normal", "large"]  # noqa: E501
        if quiet_zone_size not in allowed_values:
            raise ValueError(
                "Invalid value for `quiet_zone_size` ({0}), must be one of {1}"  # noqa: E501
                .format(quiet_zone_size, allowed_values)
            )

        self._quiet_zone_size = quiet_zone_size

    @property
    def pdf_reading_type(self):
        """Gets the pdf_reading_type of this ReadBarcodeAction.  # noqa: E501


        :return: The pdf_reading_type of this ReadBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._pdf_reading_type

    @pdf_reading_type.setter
    def pdf_reading_type(self, pdf_reading_type):
        """Sets the pdf_reading_type of this ReadBarcodeAction.


        :param pdf_reading_type: The pdf_reading_type of this ReadBarcodeAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["render", "images"]  # noqa: E501
        if pdf_reading_type not in allowed_values:
            raise ValueError(
                "Invalid value for `pdf_reading_type` ({0}), must be one of {1}"  # noqa: E501
                .format(pdf_reading_type, allowed_values)
            )

        self._pdf_reading_type = pdf_reading_type

    @property
    def pdf_render_dpi(self):
        """Gets the pdf_render_dpi of this ReadBarcodeAction.  # noqa: E501


        :return: The pdf_render_dpi of this ReadBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._pdf_render_dpi

    @pdf_render_dpi.setter
    def pdf_render_dpi(self, pdf_render_dpi):
        """Sets the pdf_render_dpi of this ReadBarcodeAction.


        :param pdf_render_dpi: The pdf_render_dpi of this ReadBarcodeAction.  # noqa: E501
        :type: int
        """

        self._pdf_render_dpi = pdf_render_dpi

    @property
    def threshold_mode(self):
        """Gets the threshold_mode of this ReadBarcodeAction.  # noqa: E501


        :return: The threshold_mode of this ReadBarcodeAction.  # noqa: E501
        :rtype: str
        """
        return self._threshold_mode

    @threshold_mode.setter
    def threshold_mode(self, threshold_mode):
        """Sets the threshold_mode of this ReadBarcodeAction.


        :param threshold_mode: The threshold_mode of this ReadBarcodeAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["automatic", "fixed", "multiple", "adaptive"]  # noqa: E501
        if threshold_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `threshold_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(threshold_mode, allowed_values)
            )

        self._threshold_mode = threshold_mode

    @property
    def threshold_count(self):
        """Gets the threshold_count of this ReadBarcodeAction.  # noqa: E501


        :return: The threshold_count of this ReadBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._threshold_count

    @threshold_count.setter
    def threshold_count(self, threshold_count):
        """Sets the threshold_count of this ReadBarcodeAction.


        :param threshold_count: The threshold_count of this ReadBarcodeAction.  # noqa: E501
        :type: int
        """

        self._threshold_count = threshold_count

    @property
    def threshold_step(self):
        """Gets the threshold_step of this ReadBarcodeAction.  # noqa: E501


        :return: The threshold_step of this ReadBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._threshold_step

    @threshold_step.setter
    def threshold_step(self, threshold_step):
        """Sets the threshold_step of this ReadBarcodeAction.


        :param threshold_step: The threshold_step of this ReadBarcodeAction.  # noqa: E501
        :type: int
        """

        self._threshold_step = threshold_step

    @property
    def scan_page(self):
        """Gets the scan_page of this ReadBarcodeAction.  # noqa: E501


        :return: The scan_page of this ReadBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._scan_page

    @scan_page.setter
    def scan_page(self, scan_page):
        """Sets the scan_page of this ReadBarcodeAction.


        :param scan_page: The scan_page of this ReadBarcodeAction.  # noqa: E501
        :type: int
        """

        self._scan_page = scan_page

    @property
    def i2of5_checksum(self):
        """Gets the i2of5_checksum of this ReadBarcodeAction.  # noqa: E501


        :return: The i2of5_checksum of this ReadBarcodeAction.  # noqa: E501
        :rtype: bool
        """
        return self._i2of5_checksum

    @i2of5_checksum.setter
    def i2of5_checksum(self, i2of5_checksum):
        """Sets the i2of5_checksum of this ReadBarcodeAction.


        :param i2of5_checksum: The i2of5_checksum of this ReadBarcodeAction.  # noqa: E501
        :type: bool
        """

        self._i2of5_checksum = i2of5_checksum

    @property
    def code11_checksum(self):
        """Gets the code11_checksum of this ReadBarcodeAction.  # noqa: E501


        :return: The code11_checksum of this ReadBarcodeAction.  # noqa: E501
        :rtype: bool
        """
        return self._code11_checksum

    @code11_checksum.setter
    def code11_checksum(self, code11_checksum):
        """Sets the code11_checksum of this ReadBarcodeAction.


        :param code11_checksum: The code11_checksum of this ReadBarcodeAction.  # noqa: E501
        :type: bool
        """

        self._code11_checksum = code11_checksum

    @property
    def code39_checksum(self):
        """Gets the code39_checksum of this ReadBarcodeAction.  # noqa: E501


        :return: The code39_checksum of this ReadBarcodeAction.  # noqa: E501
        :rtype: bool
        """
        return self._code39_checksum

    @code39_checksum.setter
    def code39_checksum(self, code39_checksum):
        """Sets the code39_checksum of this ReadBarcodeAction.


        :param code39_checksum: The code39_checksum of this ReadBarcodeAction.  # noqa: E501
        :type: bool
        """

        self._code39_checksum = code39_checksum

    @property
    def code93_checksum(self):
        """Gets the code93_checksum of this ReadBarcodeAction.  # noqa: E501


        :return: The code93_checksum of this ReadBarcodeAction.  # noqa: E501
        :rtype: bool
        """
        return self._code93_checksum

    @code93_checksum.setter
    def code93_checksum(self, code93_checksum):
        """Sets the code93_checksum of this ReadBarcodeAction.


        :param code93_checksum: The code93_checksum of this ReadBarcodeAction.  # noqa: E501
        :type: bool
        """

        self._code93_checksum = code93_checksum

    @property
    def image_despeckle(self):
        """Gets the image_despeckle of this ReadBarcodeAction.  # noqa: E501


        :return: The image_despeckle of this ReadBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._image_despeckle

    @image_despeckle.setter
    def image_despeckle(self, image_despeckle):
        """Sets the image_despeckle of this ReadBarcodeAction.


        :param image_despeckle: The image_despeckle of this ReadBarcodeAction.  # noqa: E501
        :type: int
        """

        self._image_despeckle = image_despeckle

    @property
    def image_erode(self):
        """Gets the image_erode of this ReadBarcodeAction.  # noqa: E501


        :return: The image_erode of this ReadBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._image_erode

    @image_erode.setter
    def image_erode(self, image_erode):
        """Sets the image_erode of this ReadBarcodeAction.


        :param image_erode: The image_erode of this ReadBarcodeAction.  # noqa: E501
        :type: int
        """

        self._image_erode = image_erode

    @property
    def image_dilate(self):
        """Gets the image_dilate of this ReadBarcodeAction.  # noqa: E501


        :return: The image_dilate of this ReadBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._image_dilate

    @image_dilate.setter
    def image_dilate(self, image_dilate):
        """Sets the image_dilate of this ReadBarcodeAction.


        :param image_dilate: The image_dilate of this ReadBarcodeAction.  # noqa: E501
        :type: int
        """

        self._image_dilate = image_dilate

    @property
    def image_sharp(self):
        """Gets the image_sharp of this ReadBarcodeAction.  # noqa: E501


        :return: The image_sharp of this ReadBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._image_sharp

    @image_sharp.setter
    def image_sharp(self, image_sharp):
        """Sets the image_sharp of this ReadBarcodeAction.


        :param image_sharp: The image_sharp of this ReadBarcodeAction.  # noqa: E501
        :type: int
        """

        self._image_sharp = image_sharp

    @property
    def image_invert(self):
        """Gets the image_invert of this ReadBarcodeAction.  # noqa: E501


        :return: The image_invert of this ReadBarcodeAction.  # noqa: E501
        :rtype: int
        """
        return self._image_invert

    @image_invert.setter
    def image_invert(self, image_invert):
        """Sets the image_invert of this ReadBarcodeAction.


        :param image_invert: The image_invert of this ReadBarcodeAction.  # noqa: E501
        :type: int
        """

        self._image_invert = image_invert

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReadBarcodeAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReadBarcodeAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.integration_config import IntegrationConfig  # noqa: F401,E501


class Integration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'integration_id': 'str',
        'folder': 'str',
        'integration_alias': 'str',
        'name': 'str',
        'integration_type': 'str',
        'integration_config': 'IntegrationConfig',
        'application_id': 'str',
        'enabled': 'bool',
        'basic_token': 'str',
        'mod_date': 'datetime',
        'mod_name': 'str',
        'url': 'str',
        'request_type': 'str',
        'execution_order': 'int'
    }

    attribute_map = {
        'integration_id': 'integrationId',
        'folder': 'folder',
        'integration_alias': 'integrationAlias',
        'name': 'name',
        'integration_type': 'integrationType',
        'integration_config': 'integrationConfig',
        'application_id': 'applicationId',
        'enabled': 'enabled',
        'basic_token': 'basicToken',
        'mod_date': 'modDate',
        'mod_name': 'modName',
        'url': 'url',
        'request_type': 'requestType',
        'execution_order': 'executionOrder'
    }

    def __init__(self, integration_id=None, folder=None, integration_alias=None, name=None, integration_type=None, integration_config=None, application_id=None, enabled=None, basic_token=None, mod_date=None, mod_name=None, url=None, request_type=None, execution_order=None):  # noqa: E501
        """Integration - a model defined in Swagger"""  # noqa: E501

        self._integration_id = None
        self._folder = None
        self._integration_alias = None
        self._name = None
        self._integration_type = None
        self._integration_config = None
        self._application_id = None
        self._enabled = None
        self._basic_token = None
        self._mod_date = None
        self._mod_name = None
        self._url = None
        self._request_type = None
        self._execution_order = None
        self.discriminator = None

        if integration_id is not None:
            self.integration_id = integration_id
        if folder is not None:
            self.folder = folder
        if integration_alias is not None:
            self.integration_alias = integration_alias
        if name is not None:
            self.name = name
        if integration_type is not None:
            self.integration_type = integration_type
        if integration_config is not None:
            self.integration_config = integration_config
        if application_id is not None:
            self.application_id = application_id
        if enabled is not None:
            self.enabled = enabled
        if basic_token is not None:
            self.basic_token = basic_token
        if mod_date is not None:
            self.mod_date = mod_date
        if mod_name is not None:
            self.mod_name = mod_name
        if url is not None:
            self.url = url
        if request_type is not None:
            self.request_type = request_type
        if execution_order is not None:
            self.execution_order = execution_order

    @property
    def integration_id(self):
        """Gets the integration_id of this Integration.  # noqa: E501


        :return: The integration_id of this Integration.  # noqa: E501
        :rtype: str
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """Sets the integration_id of this Integration.


        :param integration_id: The integration_id of this Integration.  # noqa: E501
        :type: str
        """

        self._integration_id = integration_id

    @property
    def folder(self):
        """Gets the folder of this Integration.  # noqa: E501


        :return: The folder of this Integration.  # noqa: E501
        :rtype: str
        """
        return self._folder

    @folder.setter
    def folder(self, folder):
        """Sets the folder of this Integration.


        :param folder: The folder of this Integration.  # noqa: E501
        :type: str
        """

        self._folder = folder

    @property
    def integration_alias(self):
        """Gets the integration_alias of this Integration.  # noqa: E501


        :return: The integration_alias of this Integration.  # noqa: E501
        :rtype: str
        """
        return self._integration_alias

    @integration_alias.setter
    def integration_alias(self, integration_alias):
        """Sets the integration_alias of this Integration.


        :param integration_alias: The integration_alias of this Integration.  # noqa: E501
        :type: str
        """

        self._integration_alias = integration_alias

    @property
    def name(self):
        """Gets the name of this Integration.  # noqa: E501


        :return: The name of this Integration.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Integration.


        :param name: The name of this Integration.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def integration_type(self):
        """Gets the integration_type of this Integration.  # noqa: E501


        :return: The integration_type of this Integration.  # noqa: E501
        :rtype: str
        """
        return self._integration_type

    @integration_type.setter
    def integration_type(self, integration_type):
        """Sets the integration_type of this Integration.


        :param integration_type: The integration_type of this Integration.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "azureStorage", "oneDrive", "sFTP", "fTP", "amazonS3", "amazonGlacier", "googleCloud", "googleDrive", "webHook", "dropbox", "azureBus", "awsSQS", "awsSNS", "azureEventHub", "signingSwissQuoVadisSealsign"]  # noqa: E501
        if integration_type not in allowed_values:
            raise ValueError(
                "Invalid value for `integration_type` ({0}), must be one of {1}"  # noqa: E501
                .format(integration_type, allowed_values)
            )

        self._integration_type = integration_type

    @property
    def integration_config(self):
        """Gets the integration_config of this Integration.  # noqa: E501


        :return: The integration_config of this Integration.  # noqa: E501
        :rtype: IntegrationConfig
        """
        return self._integration_config

    @integration_config.setter
    def integration_config(self, integration_config):
        """Sets the integration_config of this Integration.


        :param integration_config: The integration_config of this Integration.  # noqa: E501
        :type: IntegrationConfig
        """

        self._integration_config = integration_config

    @property
    def application_id(self):
        """Gets the application_id of this Integration.  # noqa: E501


        :return: The application_id of this Integration.  # noqa: E501
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """Sets the application_id of this Integration.


        :param application_id: The application_id of this Integration.  # noqa: E501
        :type: str
        """

        self._application_id = application_id

    @property
    def enabled(self):
        """Gets the enabled of this Integration.  # noqa: E501


        :return: The enabled of this Integration.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this Integration.


        :param enabled: The enabled of this Integration.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def basic_token(self):
        """Gets the basic_token of this Integration.  # noqa: E501


        :return: The basic_token of this Integration.  # noqa: E501
        :rtype: str
        """
        return self._basic_token

    @basic_token.setter
    def basic_token(self, basic_token):
        """Sets the basic_token of this Integration.


        :param basic_token: The basic_token of this Integration.  # noqa: E501
        :type: str
        """

        self._basic_token = basic_token

    @property
    def mod_date(self):
        """Gets the mod_date of this Integration.  # noqa: E501


        :return: The mod_date of this Integration.  # noqa: E501
        :rtype: datetime
        """
        return self._mod_date

    @mod_date.setter
    def mod_date(self, mod_date):
        """Sets the mod_date of this Integration.


        :param mod_date: The mod_date of this Integration.  # noqa: E501
        :type: datetime
        """

        self._mod_date = mod_date

    @property
    def mod_name(self):
        """Gets the mod_name of this Integration.  # noqa: E501


        :return: The mod_name of this Integration.  # noqa: E501
        :rtype: str
        """
        return self._mod_name

    @mod_name.setter
    def mod_name(self, mod_name):
        """Sets the mod_name of this Integration.


        :param mod_name: The mod_name of this Integration.  # noqa: E501
        :type: str
        """

        self._mod_name = mod_name

    @property
    def url(self):
        """Gets the url of this Integration.  # noqa: E501


        :return: The url of this Integration.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Integration.


        :param url: The url of this Integration.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def request_type(self):
        """Gets the request_type of this Integration.  # noqa: E501


        :return: The request_type of this Integration.  # noqa: E501
        :rtype: str
        """
        return self._request_type

    @request_type.setter
    def request_type(self, request_type):
        """Sets the request_type of this Integration.


        :param request_type: The request_type of this Integration.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "all", "onRequest"]  # noqa: E501
        if request_type not in allowed_values:
            raise ValueError(
                "Invalid value for `request_type` ({0}), must be one of {1}"  # noqa: E501
                .format(request_type, allowed_values)
            )

        self._request_type = request_type

    @property
    def execution_order(self):
        """Gets the execution_order of this Integration.  # noqa: E501


        :return: The execution_order of this Integration.  # noqa: E501
        :rtype: int
        """
        return self._execution_order

    @execution_order.setter
    def execution_order(self, execution_order):
        """Sets the execution_order of this Integration.


        :param execution_order: The execution_order of this Integration.  # noqa: E501
        :type: int
        """

        self._execution_order = execution_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Integration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Integration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.key_value_pair_string_object import KeyValuePairStringObject  # noqa: F401,E501
from pdf4me.model.value_type import ValueType  # noqa: F401,E501


class ScanBarcode(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'barcode_data_type': 'str',
        'barcode_type': 'str',
        'barcode_data_len': 'int',
        'angle': 'float',
        'border_end_x1': 'int',
        'border_end_x2': 'int',
        'border_end_y1': 'int',
        'border_end_y2': 'int',
        'border_start_x1': 'int',
        'border_start_x2': 'int',
        'border_start_y1': 'int',
        'border_start_y2': 'int',
        'top': 'int',
        'left': 'int',
        'right': 'int',
        'bottom': 'int',
        'bounding_rectangle': 'ValueType',
        'checksum': 'int',
        'rss_expanded_stacked': 'int',
        'type': 'str',
        'threshold': 'int',
        'page': 'int',
        'orientation_string': 'str',
        'orientation': 'str',
        'barcode_info_string': 'str',
        'barcode_data': 'str',
        'qr_version': 'int',
        'num_errors_corrected': 'int',
        'dim2': 'int',
        'dim1': 'int',
        'data_matrix_num_errors_corrected': 'int',
        'data_matrix_dim2': 'int',
        'data_matrix_dim1': 'int',
        'error_correction_level': 'int',
        'barcode_string': 'str',
        'properties': 'list[KeyValuePairStringObject]'
    }

    attribute_map = {
        'barcode_data_type': 'barcodeDataType',
        'barcode_type': 'barcodeType',
        'barcode_data_len': 'barcodeDataLen',
        'angle': 'angle',
        'border_end_x1': 'borderEndX1',
        'border_end_x2': 'borderEndX2',
        'border_end_y1': 'borderEndY1',
        'border_end_y2': 'borderEndY2',
        'border_start_x1': 'borderStartX1',
        'border_start_x2': 'borderStartX2',
        'border_start_y1': 'borderStartY1',
        'border_start_y2': 'borderStartY2',
        'top': 'top',
        'left': 'left',
        'right': 'right',
        'bottom': 'bottom',
        'bounding_rectangle': 'boundingRectangle',
        'checksum': 'checksum',
        'rss_expanded_stacked': 'rssExpandedStacked',
        'type': 'type',
        'threshold': 'threshold',
        'page': 'page',
        'orientation_string': 'orientationString',
        'orientation': 'orientation',
        'barcode_info_string': 'barcodeInfoString',
        'barcode_data': 'barcodeData',
        'qr_version': 'qrVersion',
        'num_errors_corrected': 'numErrorsCorrected',
        'dim2': 'dim2',
        'dim1': 'dim1',
        'data_matrix_num_errors_corrected': 'dataMatrix_NumErrorsCorrected',
        'data_matrix_dim2': 'dataMatrix_Dim2',
        'data_matrix_dim1': 'dataMatrix_Dim1',
        'error_correction_level': 'errorCorrectionLevel',
        'barcode_string': 'barcodeString',
        'properties': 'properties'
    }

    def __init__(self, barcode_data_type=None, barcode_type=None, barcode_data_len=None, angle=None, border_end_x1=None, border_end_x2=None, border_end_y1=None, border_end_y2=None, border_start_x1=None, border_start_x2=None, border_start_y1=None, border_start_y2=None, top=None, left=None, right=None, bottom=None, bounding_rectangle=None, checksum=None, rss_expanded_stacked=None, type=None, threshold=None, page=None, orientation_string=None, orientation=None, barcode_info_string=None, barcode_data=None, qr_version=None, num_errors_corrected=None, dim2=None, dim1=None, data_matrix_num_errors_corrected=None, data_matrix_dim2=None, data_matrix_dim1=None, error_correction_level=None, barcode_string=None, properties=None):  # noqa: E501
        """ScanBarcode - a model defined in Swagger"""  # noqa: E501

        self._barcode_data_type = None
        self._barcode_type = None
        self._barcode_data_len = None
        self._angle = None
        self._border_end_x1 = None
        self._border_end_x2 = None
        self._border_end_y1 = None
        self._border_end_y2 = None
        self._border_start_x1 = None
        self._border_start_x2 = None
        self._border_start_y1 = None
        self._border_start_y2 = None
        self._top = None
        self._left = None
        self._right = None
        self._bottom = None
        self._bounding_rectangle = None
        self._checksum = None
        self._rss_expanded_stacked = None
        self._type = None
        self._threshold = None
        self._page = None
        self._orientation_string = None
        self._orientation = None
        self._barcode_info_string = None
        self._barcode_data = None
        self._qr_version = None
        self._num_errors_corrected = None
        self._dim2 = None
        self._dim1 = None
        self._data_matrix_num_errors_corrected = None
        self._data_matrix_dim2 = None
        self._data_matrix_dim1 = None
        self._error_correction_level = None
        self._barcode_string = None
        self._properties = None
        self.discriminator = None

        if barcode_data_type is not None:
            self.barcode_data_type = barcode_data_type
        if barcode_type is not None:
            self.barcode_type = barcode_type
        if barcode_data_len is not None:
            self.barcode_data_len = barcode_data_len
        if angle is not None:
            self.angle = angle
        if border_end_x1 is not None:
            self.border_end_x1 = border_end_x1
        if border_end_x2 is not None:
            self.border_end_x2 = border_end_x2
        if border_end_y1 is not None:
            self.border_end_y1 = border_end_y1
        if border_end_y2 is not None:
            self.border_end_y2 = border_end_y2
        if border_start_x1 is not None:
            self.border_start_x1 = border_start_x1
        if border_start_x2 is not None:
            self.border_start_x2 = border_start_x2
        if border_start_y1 is not None:
            self.border_start_y1 = border_start_y1
        if border_start_y2 is not None:
            self.border_start_y2 = border_start_y2
        if top is not None:
            self.top = top
        if left is not None:
            self.left = left
        if right is not None:
            self.right = right
        if bottom is not None:
            self.bottom = bottom
        if bounding_rectangle is not None:
            self.bounding_rectangle = bounding_rectangle
        if checksum is not None:
            self.checksum = checksum
        if rss_expanded_stacked is not None:
            self.rss_expanded_stacked = rss_expanded_stacked
        if type is not None:
            self.type = type
        if threshold is not None:
            self.threshold = threshold
        if page is not None:
            self.page = page
        if orientation_string is not None:
            self.orientation_string = orientation_string
        if orientation is not None:
            self.orientation = orientation
        if barcode_info_string is not None:
            self.barcode_info_string = barcode_info_string
        if barcode_data is not None:
            self.barcode_data = barcode_data
        if qr_version is not None:
            self.qr_version = qr_version
        if num_errors_corrected is not None:
            self.num_errors_corrected = num_errors_corrected
        if dim2 is not None:
            self.dim2 = dim2
        if dim1 is not None:
            self.dim1 = dim1
        if data_matrix_num_errors_corrected is not None:
            self.data_matrix_num_errors_corrected = data_matrix_num_errors_corrected
        if data_matrix_dim2 is not None:
            self.data_matrix_dim2 = data_matrix_dim2
        if data_matrix_dim1 is not None:
            self.data_matrix_dim1 = data_matrix_dim1
        if error_correction_level is not None:
            self.error_correction_level = error_correction_level
        if barcode_string is not None:
            self.barcode_string = barcode_string
        if properties is not None:
            self.properties = properties

    @property
    def barcode_data_type(self):
        """Gets the barcode_data_type of this ScanBarcode.  # noqa: E501


        :return: The barcode_data_type of this ScanBarcode.  # noqa: E501
        :rtype: str
        """
        return self._barcode_data_type

    @barcode_data_type.setter
    def barcode_data_type(self, barcode_data_type):
        """Sets the barcode_data_type of this ScanBarcode.


        :param barcode_data_type: The barcode_data_type of this ScanBarcode.  # noqa: E501
        :type: str
        """

        self._barcode_data_type = barcode_data_type

    @property
    def barcode_type(self):
        """Gets the barcode_type of this ScanBarcode.  # noqa: E501


        :return: The barcode_type of this ScanBarcode.  # noqa: E501
        :rtype: str
        """
        return self._barcode_type

    @barcode_type.setter
    def barcode_type(self, barcode_type):
        """Sets the barcode_type of this ScanBarcode.


        :param barcode_type: The barcode_type of this ScanBarcode.  # noqa: E501
        :type: str
        """
        allowed_values = ["all", "unknown", "code11", "code39", "code93", "code128", "codabar", "inter2of5", "patchCode", "ean8", "upce", "ean13", "upca", "plus2", "plus5", "pdf417", "dataMatrix", "qrCode", "postnet", "planet", "rm4SCC", "australiaPost", "intelligentMail", "code39Extended", "microQRCode", "all_2D", "pharmaCode", "ucc128", "rss14", "rssLimited", "rssExpanded", "all_1D"]  # noqa: E501
        if barcode_type not in allowed_values:
            raise ValueError(
                "Invalid value for `barcode_type` ({0}), must be one of {1}"  # noqa: E501
                .format(barcode_type, allowed_values)
            )

        self._barcode_type = barcode_type

    @property
    def barcode_data_len(self):
        """Gets the barcode_data_len of this ScanBarcode.  # noqa: E501


        :return: The barcode_data_len of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._barcode_data_len

    @barcode_data_len.setter
    def barcode_data_len(self, barcode_data_len):
        """Sets the barcode_data_len of this ScanBarcode.


        :param barcode_data_len: The barcode_data_len of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._barcode_data_len = barcode_data_len

    @property
    def angle(self):
        """Gets the angle of this ScanBarcode.  # noqa: E501


        :return: The angle of this ScanBarcode.  # noqa: E501
        :rtype: float
        """
        return self._angle

    @angle.setter
    def angle(self, angle):
        """Sets the angle of this ScanBarcode.


        :param angle: The angle of this ScanBarcode.  # noqa: E501
        :type: float
        """

        self._angle = angle

    @property
    def border_end_x1(self):
        """Gets the border_end_x1 of this ScanBarcode.  # noqa: E501


        :return: The border_end_x1 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._border_end_x1

    @border_end_x1.setter
    def border_end_x1(self, border_end_x1):
        """Sets the border_end_x1 of this ScanBarcode.


        :param border_end_x1: The border_end_x1 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._border_end_x1 = border_end_x1

    @property
    def border_end_x2(self):
        """Gets the border_end_x2 of this ScanBarcode.  # noqa: E501


        :return: The border_end_x2 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._border_end_x2

    @border_end_x2.setter
    def border_end_x2(self, border_end_x2):
        """Sets the border_end_x2 of this ScanBarcode.


        :param border_end_x2: The border_end_x2 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._border_end_x2 = border_end_x2

    @property
    def border_end_y1(self):
        """Gets the border_end_y1 of this ScanBarcode.  # noqa: E501


        :return: The border_end_y1 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._border_end_y1

    @border_end_y1.setter
    def border_end_y1(self, border_end_y1):
        """Sets the border_end_y1 of this ScanBarcode.


        :param border_end_y1: The border_end_y1 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._border_end_y1 = border_end_y1

    @property
    def border_end_y2(self):
        """Gets the border_end_y2 of this ScanBarcode.  # noqa: E501


        :return: The border_end_y2 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._border_end_y2

    @border_end_y2.setter
    def border_end_y2(self, border_end_y2):
        """Sets the border_end_y2 of this ScanBarcode.


        :param border_end_y2: The border_end_y2 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._border_end_y2 = border_end_y2

    @property
    def border_start_x1(self):
        """Gets the border_start_x1 of this ScanBarcode.  # noqa: E501


        :return: The border_start_x1 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._border_start_x1

    @border_start_x1.setter
    def border_start_x1(self, border_start_x1):
        """Sets the border_start_x1 of this ScanBarcode.


        :param border_start_x1: The border_start_x1 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._border_start_x1 = border_start_x1

    @property
    def border_start_x2(self):
        """Gets the border_start_x2 of this ScanBarcode.  # noqa: E501


        :return: The border_start_x2 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._border_start_x2

    @border_start_x2.setter
    def border_start_x2(self, border_start_x2):
        """Sets the border_start_x2 of this ScanBarcode.


        :param border_start_x2: The border_start_x2 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._border_start_x2 = border_start_x2

    @property
    def border_start_y1(self):
        """Gets the border_start_y1 of this ScanBarcode.  # noqa: E501


        :return: The border_start_y1 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._border_start_y1

    @border_start_y1.setter
    def border_start_y1(self, border_start_y1):
        """Sets the border_start_y1 of this ScanBarcode.


        :param border_start_y1: The border_start_y1 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._border_start_y1 = border_start_y1

    @property
    def border_start_y2(self):
        """Gets the border_start_y2 of this ScanBarcode.  # noqa: E501


        :return: The border_start_y2 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._border_start_y2

    @border_start_y2.setter
    def border_start_y2(self, border_start_y2):
        """Sets the border_start_y2 of this ScanBarcode.


        :param border_start_y2: The border_start_y2 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._border_start_y2 = border_start_y2

    @property
    def top(self):
        """Gets the top of this ScanBarcode.  # noqa: E501


        :return: The top of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._top

    @top.setter
    def top(self, top):
        """Sets the top of this ScanBarcode.


        :param top: The top of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._top = top

    @property
    def left(self):
        """Gets the left of this ScanBarcode.  # noqa: E501


        :return: The left of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._left

    @left.setter
    def left(self, left):
        """Sets the left of this ScanBarcode.


        :param left: The left of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._left = left

    @property
    def right(self):
        """Gets the right of this ScanBarcode.  # noqa: E501


        :return: The right of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._right

    @right.setter
    def right(self, right):
        """Sets the right of this ScanBarcode.


        :param right: The right of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._right = right

    @property
    def bottom(self):
        """Gets the bottom of this ScanBarcode.  # noqa: E501


        :return: The bottom of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._bottom

    @bottom.setter
    def bottom(self, bottom):
        """Sets the bottom of this ScanBarcode.


        :param bottom: The bottom of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._bottom = bottom

    @property
    def bounding_rectangle(self):
        """Gets the bounding_rectangle of this ScanBarcode.  # noqa: E501


        :return: The bounding_rectangle of this ScanBarcode.  # noqa: E501
        :rtype: ValueType
        """
        return self._bounding_rectangle

    @bounding_rectangle.setter
    def bounding_rectangle(self, bounding_rectangle):
        """Sets the bounding_rectangle of this ScanBarcode.


        :param bounding_rectangle: The bounding_rectangle of this ScanBarcode.  # noqa: E501
        :type: ValueType
        """

        self._bounding_rectangle = bounding_rectangle

    @property
    def checksum(self):
        """Gets the checksum of this ScanBarcode.  # noqa: E501


        :return: The checksum of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._checksum

    @checksum.setter
    def checksum(self, checksum):
        """Sets the checksum of this ScanBarcode.


        :param checksum: The checksum of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._checksum = checksum

    @property
    def rss_expanded_stacked(self):
        """Gets the rss_expanded_stacked of this ScanBarcode.  # noqa: E501


        :return: The rss_expanded_stacked of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._rss_expanded_stacked

    @rss_expanded_stacked.setter
    def rss_expanded_stacked(self, rss_expanded_stacked):
        """Sets the rss_expanded_stacked of this ScanBarcode.


        :param rss_expanded_stacked: The rss_expanded_stacked of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._rss_expanded_stacked = rss_expanded_stacked

    @property
    def type(self):
        """Gets the type of this ScanBarcode.  # noqa: E501


        :return: The type of this ScanBarcode.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ScanBarcode.


        :param type: The type of this ScanBarcode.  # noqa: E501
        :type: str
        """
        allowed_values = ["all", "unknown", "code11", "code39", "code93", "code128", "codabar", "inter2of5", "patchCode", "ean8", "upce", "ean13", "upca", "plus2", "plus5", "pdf417", "dataMatrix", "qrCode", "postnet", "planet", "rm4SCC", "australiaPost", "intelligentMail", "code39Extended", "microQRCode", "all_2D", "pharmaCode", "ucc128", "rss14", "rssLimited", "rssExpanded", "all_1D"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def threshold(self):
        """Gets the threshold of this ScanBarcode.  # noqa: E501


        :return: The threshold of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this ScanBarcode.


        :param threshold: The threshold of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._threshold = threshold

    @property
    def page(self):
        """Gets the page of this ScanBarcode.  # noqa: E501


        :return: The page of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this ScanBarcode.


        :param page: The page of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def orientation_string(self):
        """Gets the orientation_string of this ScanBarcode.  # noqa: E501


        :return: The orientation_string of this ScanBarcode.  # noqa: E501
        :rtype: str
        """
        return self._orientation_string

    @orientation_string.setter
    def orientation_string(self, orientation_string):
        """Sets the orientation_string of this ScanBarcode.


        :param orientation_string: The orientation_string of this ScanBarcode.  # noqa: E501
        :type: str
        """

        self._orientation_string = orientation_string

    @property
    def orientation(self):
        """Gets the orientation of this ScanBarcode.  # noqa: E501


        :return: The orientation of this ScanBarcode.  # noqa: E501
        :rtype: str
        """
        return self._orientation

    @orientation.setter
    def orientation(self, orientation):
        """Sets the orientation of this ScanBarcode.


        :param orientation: The orientation of this ScanBarcode.  # noqa: E501
        :type: str
        """
        allowed_values = ["unknown", "leftToRight", "rightToLeft", "topToBottom", "bottomToTop", "all"]  # noqa: E501
        if orientation not in allowed_values:
            raise ValueError(
                "Invalid value for `orientation` ({0}), must be one of {1}"  # noqa: E501
                .format(orientation, allowed_values)
            )

        self._orientation = orientation

    @property
    def barcode_info_string(self):
        """Gets the barcode_info_string of this ScanBarcode.  # noqa: E501


        :return: The barcode_info_string of this ScanBarcode.  # noqa: E501
        :rtype: str
        """
        return self._barcode_info_string

    @barcode_info_string.setter
    def barcode_info_string(self, barcode_info_string):
        """Sets the barcode_info_string of this ScanBarcode.


        :param barcode_info_string: The barcode_info_string of this ScanBarcode.  # noqa: E501
        :type: str
        """

        self._barcode_info_string = barcode_info_string

    @property
    def barcode_data(self):
        """Gets the barcode_data of this ScanBarcode.  # noqa: E501


        :return: The barcode_data of this ScanBarcode.  # noqa: E501
        :rtype: str
        """
        return self._barcode_data

    @barcode_data.setter
    def barcode_data(self, barcode_data):
        """Sets the barcode_data of this ScanBarcode.


        :param barcode_data: The barcode_data of this ScanBarcode.  # noqa: E501
        :type: str
        """
        if barcode_data is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', barcode_data):  # noqa: E501
            raise ValueError(r"Invalid value for `barcode_data`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._barcode_data = barcode_data

    @property
    def qr_version(self):
        """Gets the qr_version of this ScanBarcode.  # noqa: E501


        :return: The qr_version of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._qr_version

    @qr_version.setter
    def qr_version(self, qr_version):
        """Sets the qr_version of this ScanBarcode.


        :param qr_version: The qr_version of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._qr_version = qr_version

    @property
    def num_errors_corrected(self):
        """Gets the num_errors_corrected of this ScanBarcode.  # noqa: E501


        :return: The num_errors_corrected of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._num_errors_corrected

    @num_errors_corrected.setter
    def num_errors_corrected(self, num_errors_corrected):
        """Sets the num_errors_corrected of this ScanBarcode.


        :param num_errors_corrected: The num_errors_corrected of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._num_errors_corrected = num_errors_corrected

    @property
    def dim2(self):
        """Gets the dim2 of this ScanBarcode.  # noqa: E501


        :return: The dim2 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._dim2

    @dim2.setter
    def dim2(self, dim2):
        """Sets the dim2 of this ScanBarcode.


        :param dim2: The dim2 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._dim2 = dim2

    @property
    def dim1(self):
        """Gets the dim1 of this ScanBarcode.  # noqa: E501


        :return: The dim1 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._dim1

    @dim1.setter
    def dim1(self, dim1):
        """Sets the dim1 of this ScanBarcode.


        :param dim1: The dim1 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._dim1 = dim1

    @property
    def data_matrix_num_errors_corrected(self):
        """Gets the data_matrix_num_errors_corrected of this ScanBarcode.  # noqa: E501


        :return: The data_matrix_num_errors_corrected of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._data_matrix_num_errors_corrected

    @data_matrix_num_errors_corrected.setter
    def data_matrix_num_errors_corrected(self, data_matrix_num_errors_corrected):
        """Sets the data_matrix_num_errors_corrected of this ScanBarcode.


        :param data_matrix_num_errors_corrected: The data_matrix_num_errors_corrected of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._data_matrix_num_errors_corrected = data_matrix_num_errors_corrected

    @property
    def data_matrix_dim2(self):
        """Gets the data_matrix_dim2 of this ScanBarcode.  # noqa: E501


        :return: The data_matrix_dim2 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._data_matrix_dim2

    @data_matrix_dim2.setter
    def data_matrix_dim2(self, data_matrix_dim2):
        """Sets the data_matrix_dim2 of this ScanBarcode.


        :param data_matrix_dim2: The data_matrix_dim2 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._data_matrix_dim2 = data_matrix_dim2

    @property
    def data_matrix_dim1(self):
        """Gets the data_matrix_dim1 of this ScanBarcode.  # noqa: E501


        :return: The data_matrix_dim1 of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._data_matrix_dim1

    @data_matrix_dim1.setter
    def data_matrix_dim1(self, data_matrix_dim1):
        """Sets the data_matrix_dim1 of this ScanBarcode.


        :param data_matrix_dim1: The data_matrix_dim1 of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._data_matrix_dim1 = data_matrix_dim1

    @property
    def error_correction_level(self):
        """Gets the error_correction_level of this ScanBarcode.  # noqa: E501


        :return: The error_correction_level of this ScanBarcode.  # noqa: E501
        :rtype: int
        """
        return self._error_correction_level

    @error_correction_level.setter
    def error_correction_level(self, error_correction_level):
        """Sets the error_correction_level of this ScanBarcode.


        :param error_correction_level: The error_correction_level of this ScanBarcode.  # noqa: E501
        :type: int
        """

        self._error_correction_level = error_correction_level

    @property
    def barcode_string(self):
        """Gets the barcode_string of this ScanBarcode.  # noqa: E501


        :return: The barcode_string of this ScanBarcode.  # noqa: E501
        :rtype: str
        """
        return self._barcode_string

    @barcode_string.setter
    def barcode_string(self, barcode_string):
        """Sets the barcode_string of this ScanBarcode.


        :param barcode_string: The barcode_string of this ScanBarcode.  # noqa: E501
        :type: str
        """

        self._barcode_string = barcode_string

    @property
    def properties(self):
        """Gets the properties of this ScanBarcode.  # noqa: E501


        :return: The properties of this ScanBarcode.  # noqa: E501
        :rtype: list[KeyValuePairStringObject]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this ScanBarcode.


        :param properties: The properties of this ScanBarcode.  # noqa: E501
        :type: list[KeyValuePairStringObject]
        """

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScanBarcode, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScanBarcode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import base64

from pdf4me.helper.pdf4me_exceptions import Pdf4meClientException
from pdf4me.model import CreateImages
from pdf4me.helper.json_converter import JsonConverter


class ImageClient(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def create_images(self, create_images):
        """The predefined image creation is carried out.

        :param create_images: image creation configuration
        :type create_images: CreateImages
        :return: CreateImagesRes, contains images
        """

        # check create_images validity
        self.__check_create_images_object_validity(create_images)

        res = self.pdf4me_client.custom_http.post_universal_object(universal_object=create_images,
                                                                   controller='Image/CreateImages')

        return res

    def create_thumbnail(self, width, page_nr, image_format, file):
        """Produces a thumbnail of the page referenced by the pageNr. Be aware of the one-indexing of the page numbers.

        :param width: size of the produced thumbnail
        :type width: int
        :param page_nr: number of the page which should be captured by the thumbnail
        :type page_nr: str
        :param image_format: picture format of thumbnail, e.g. 'jpg'
        :type image_format: str
        :param file: file to capture thumbnails from
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of produced thumbnail, can be directly written to image file on disk
        """

        streams = [('file', file)]
        params = [('width', width), ('pageNr', page_nr), ('imageFormat', image_format)]

        return self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                           controller='Image/CreateThumbnail')

    def create_thumbnails(self, width, page_nrs, image_format, file):
        """Produces a thumbnail of the page referenced by the pageNr. Be aware of the one-indexing of the page numbers.

        :param width: size of the produced thumbnail
        :type width: int
        :param page_nrs: number of the page which should be captured by the thumbnail
        :type page_nrs: str
        :param image_format: picture format of thumbnail, e.g. 'jpg'
        :type image_format: str
        :param file: file to capture thumbnails from
        :type file: file handler, use the method get_file_handler from FileReader to obtain it
        :return: bytes of produced thumbnail, can be directly written to image file on disk
        """

        streams = [('file', file)]
        params = [('width', width), ('pageNrs', page_nrs), ('imageFormat', image_format)]

        res = self.pdf4me_client.custom_http.post_wrapper(octet_streams=streams, values=params,
                                                          controller='Image/CreateThumbnails')

        # get json
        res = JsonConverter().load(res)

        # extract the two documents
        pdfs = []
        for pdf in res:
            pdfs.append(base64.b64decode(pdf))
        # pdf_1 = base64.b64decode(res[0])
        # pdf_2 = base64.b64decode(res[1])

        return pdfs

    def __check_create_images_object_validity(self, create_images):
        """Checks whether the create_images object contains the essential information to be
                processed by the server."""

        if create_images is None:
            raise Pdf4meClientException('The create_images parameter cannot be None.')
        elif create_images.document is None or create_images.document.doc_data is None:
            raise Pdf4meClientException('The create_images document cannot be None.')
        elif create_images.image_action is None:
            raise Pdf4meClientException('The image_action cannot be None.')
        elif create_images.image_action.page_selection is None:
            raise Pdf4meClientException('The page_selection of the image_action cannot be None.')



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.key_value_pair_string_string import KeyValuePairStringString  # noqa: F401,E501
from pdf4me.model.signature_config import SignatureConfig  # noqa: F401,E501
from pdf4me.model.stamp_action import StampAction  # noqa: F401,E501


class ArchiveConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'archive_metadata': 'list[KeyValuePairStringString]',
        'stamp_action': 'StampAction',
        'signature_config': 'SignatureConfig',
        'use_tsa': 'bool'
    }

    attribute_map = {
        'archive_metadata': 'archiveMetadata',
        'stamp_action': 'stampAction',
        'signature_config': 'signatureConfig',
        'use_tsa': 'useTSA'
    }

    def __init__(self, archive_metadata=None, stamp_action=None, signature_config=None, use_tsa=None):  # noqa: E501
        """ArchiveConfig - a model defined in Swagger"""  # noqa: E501

        self._archive_metadata = None
        self._stamp_action = None
        self._signature_config = None
        self._use_tsa = None
        self.discriminator = None

        self.archive_metadata = archive_metadata
        if stamp_action is not None:
            self.stamp_action = stamp_action
        if signature_config is not None:
            self.signature_config = signature_config
        if use_tsa is not None:
            self.use_tsa = use_tsa

    @property
    def archive_metadata(self):
        """Gets the archive_metadata of this ArchiveConfig.  # noqa: E501

        Give the documents metadata for archiving.  # noqa: E501

        :return: The archive_metadata of this ArchiveConfig.  # noqa: E501
        :rtype: list[KeyValuePairStringString]
        """
        return self._archive_metadata

    @archive_metadata.setter
    def archive_metadata(self, archive_metadata):
        """Sets the archive_metadata of this ArchiveConfig.

        Give the documents metadata for archiving.  # noqa: E501

        :param archive_metadata: The archive_metadata of this ArchiveConfig.  # noqa: E501
        :type: list[KeyValuePairStringString]
        """
        if archive_metadata is None:
            raise ValueError("Invalid value for `archive_metadata`, must not be `None`")  # noqa: E501

        self._archive_metadata = archive_metadata

    @property
    def stamp_action(self):
        """Gets the stamp_action of this ArchiveConfig.  # noqa: E501

        Place a signature stamp on to the document.  # noqa: E501

        :return: The stamp_action of this ArchiveConfig.  # noqa: E501
        :rtype: StampAction
        """
        return self._stamp_action

    @stamp_action.setter
    def stamp_action(self, stamp_action):
        """Sets the stamp_action of this ArchiveConfig.

        Place a signature stamp on to the document.  # noqa: E501

        :param stamp_action: The stamp_action of this ArchiveConfig.  # noqa: E501
        :type: StampAction
        """

        self._stamp_action = stamp_action

    @property
    def signature_config(self):
        """Gets the signature_config of this ArchiveConfig.  # noqa: E501

        Give your Signature Configure to get the electronical Identity.  # noqa: E501

        :return: The signature_config of this ArchiveConfig.  # noqa: E501
        :rtype: SignatureConfig
        """
        return self._signature_config

    @signature_config.setter
    def signature_config(self, signature_config):
        """Sets the signature_config of this ArchiveConfig.

        Give your Signature Configure to get the electronical Identity.  # noqa: E501

        :param signature_config: The signature_config of this ArchiveConfig.  # noqa: E501
        :type: SignatureConfig
        """

        self._signature_config = signature_config

    @property
    def use_tsa(self):
        """Gets the use_tsa of this ArchiveConfig.  # noqa: E501

        To guarantee the time of change use a Time Stamp Service.  # noqa: E501

        :return: The use_tsa of this ArchiveConfig.  # noqa: E501
        :rtype: bool
        """
        return self._use_tsa

    @use_tsa.setter
    def use_tsa(self, use_tsa):
        """Sets the use_tsa of this ArchiveConfig.

        To guarantee the time of change use a Time Stamp Service.  # noqa: E501

        :param use_tsa: The use_tsa of this ArchiveConfig.  # noqa: E501
        :type: bool
        """

        self._use_tsa = use_tsa

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ArchiveConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArchiveConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DmsApi

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.doc_log import DocLog  # noqa: F401,E501
from pdf4me.model.document import Document  # noqa: F401,E501
from pdf4me.model.pdf4me_document import Pdf4meDocument  # noqa: F401,E501
from pdf4me.model.pricing import Pricing  # noqa: F401,E501


class GetDocumentRes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'document': 'Pdf4meDocument',
        'doc_logs': 'list[DocLog]',
        'pricing': 'Pricing',
        'document_list': 'list[Document]',
        'success': 'bool',
        'error_msg': 'str',
        'exception': 'object'
    }

    attribute_map = {
        'document': 'document',
        'doc_logs': 'docLogs',
        'pricing': 'pricing',
        'document_list': 'documentList',
        'success': 'success',
        'error_msg': 'errorMsg',
        'exception': 'exception'
    }

    def __init__(self, document=None, doc_logs=None, pricing=None, document_list=None, success=None, error_msg=None, exception=None):  # noqa: E501
        """GetDocumentRes - a model defined in Swagger"""  # noqa: E501

        self._document = None
        self._doc_logs = None
        self._pricing = None
        self._document_list = None
        self._success = None
        self._error_msg = None
        self._exception = None
        self.discriminator = None

        if document is not None:
            self.document = document
        if doc_logs is not None:
            self.doc_logs = doc_logs
        if pricing is not None:
            self.pricing = pricing
        if document_list is not None:
            self.document_list = document_list
        if success is not None:
            self.success = success
        if error_msg is not None:
            self.error_msg = error_msg
        if exception is not None:
            self.exception = exception

    @property
    def document(self):
        """Gets the document of this GetDocumentRes.  # noqa: E501


        :return: The document of this GetDocumentRes.  # noqa: E501
        :rtype: Pdf4meDocument
        """
        return self._document

    @document.setter
    def document(self, document):
        """Sets the document of this GetDocumentRes.


        :param document: The document of this GetDocumentRes.  # noqa: E501
        :type: Pdf4meDocument
        """

        self._document = document

    @property
    def doc_logs(self):
        """Gets the doc_logs of this GetDocumentRes.  # noqa: E501


        :return: The doc_logs of this GetDocumentRes.  # noqa: E501
        :rtype: list[DocLog]
        """
        return self._doc_logs

    @doc_logs.setter
    def doc_logs(self, doc_logs):
        """Sets the doc_logs of this GetDocumentRes.


        :param doc_logs: The doc_logs of this GetDocumentRes.  # noqa: E501
        :type: list[DocLog]
        """

        self._doc_logs = doc_logs

    @property
    def pricing(self):
        """Gets the pricing of this GetDocumentRes.  # noqa: E501


        :return: The pricing of this GetDocumentRes.  # noqa: E501
        :rtype: Pricing
        """
        return self._pricing

    @pricing.setter
    def pricing(self, pricing):
        """Sets the pricing of this GetDocumentRes.


        :param pricing: The pricing of this GetDocumentRes.  # noqa: E501
        :type: Pricing
        """

        self._pricing = pricing

    @property
    def document_list(self):
        """Gets the document_list of this GetDocumentRes.  # noqa: E501


        :return: The document_list of this GetDocumentRes.  # noqa: E501
        :rtype: list[Document]
        """
        return self._document_list

    @document_list.setter
    def document_list(self, document_list):
        """Sets the document_list of this GetDocumentRes.


        :param document_list: The document_list of this GetDocumentRes.  # noqa: E501
        :type: list[Document]
        """

        self._document_list = document_list

    @property
    def success(self):
        """Gets the success of this GetDocumentRes.  # noqa: E501


        :return: The success of this GetDocumentRes.  # noqa: E501
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this GetDocumentRes.


        :param success: The success of this GetDocumentRes.  # noqa: E501
        :type: bool
        """

        self._success = success

    @property
    def error_msg(self):
        """Gets the error_msg of this GetDocumentRes.  # noqa: E501


        :return: The error_msg of this GetDocumentRes.  # noqa: E501
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        """Sets the error_msg of this GetDocumentRes.


        :param error_msg: The error_msg of this GetDocumentRes.  # noqa: E501
        :type: str
        """

        self._error_msg = error_msg

    @property
    def exception(self):
        """Gets the exception of this GetDocumentRes.  # noqa: E501


        :return: The exception of this GetDocumentRes.  # noqa: E501
        :rtype: object
        """
        return self._exception

    @exception.setter
    def exception(self, exception):
        """Sets the exception of this GetDocumentRes.


        :param exception: The exception of this GetDocumentRes.  # noqa: E501
        :type: object
        """

        self._exception = exception

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetDocumentRes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from pdf4me.model.action_flow import ActionFlow
from pdf4me.model.api_call_detail import ApiCallDetail
from pdf4me.model.archive_config import ArchiveConfig
from pdf4me.model.archive_job_req import ArchiveJobReq
from pdf4me.model.archive_job_res import ArchiveJobRes
from pdf4me.model.check_availability_res import CheckAvailabilityRes
from pdf4me.model.color import Color
from pdf4me.model.convert_to_pdf import ConvertToPdf
from pdf4me.model.convert_to_pdf_action import ConvertToPdfAction
from pdf4me.model.convert_to_pdf_res import ConvertToPdfRes
from pdf4me.model.create_images import CreateImages
from pdf4me.model.create_images_res import CreateImagesRes
from pdf4me.model.create_pdf_a import CreatePdfA
from pdf4me.model.create_pdf_a_res import CreatePdfARes
from pdf4me.model.custom_cms_config import CustomCMSConfig
from pdf4me.model.doc_action import DocAction
from pdf4me.model.doc_log import DocLog
from pdf4me.model.doc_metadata import DocMetadata
from pdf4me.model.document import Document
from pdf4me.model.drop_document_req import DropDocumentReq
from pdf4me.model.drop_document_res import DropDocumentRes
from pdf4me.model.execution_trigger import ExecutionTrigger
from pdf4me.model.extract import Extract
from pdf4me.model.extract_action import ExtractAction
from pdf4me.model.extract_res import ExtractRes
from pdf4me.model.extract_resources import ExtractResources
from pdf4me.model.extract_resources_action import ExtractResourcesAction
from pdf4me.model.extract_resources_res import ExtractResourcesRes
from pdf4me.model.get_document_list_res import GetDocumentListRes
from pdf4me.model.get_document_url_res import GetDocumentUrlRes
from pdf4me.model.image import Image
from pdf4me.model.image_action import ImageAction
from pdf4me.model.integration import Integration
from pdf4me.model.integration_call import IntegrationCall
from pdf4me.model.integration_config import IntegrationConfig
from pdf4me.model.integration_setting import IntegrationSetting
from pdf4me.model.job import Job
from pdf4me.model.job_config import JobConfig
from pdf4me.model.job_config_res import JobConfigRes
from pdf4me.model.job_flow import JobFlow
from pdf4me.model.job_flow_plan import JobFlowPlan
from pdf4me.model.key_value_pair_string_object import KeyValuePairStringObject
from pdf4me.model.key_value_pair_string_string import KeyValuePairStringString
from pdf4me.model.merge import Merge
from pdf4me.model.merge_action import MergeAction
from pdf4me.model.merge_res import MergeRes
from pdf4me.model.notification import Notification
from pdf4me.model.ocr_action import OcrAction
from pdf4me.model.optimize import Optimize
from pdf4me.model.optimize_action import OptimizeAction
from pdf4me.model.optimize_res import OptimizeRes
from pdf4me.model.page import Page
from pdf4me.model.page_selection import PageSelection
from pdf4me.model.pdf4me_action import Pdf4meAction
from pdf4me.model.pdf4me_document import Pdf4meDocument
from pdf4me.model.pdf4me_exception import Pdf4meException
from pdf4me.model.pdf_a_action import PdfAAction
from pdf4me.model.pdf_font import PdfFont
from pdf4me.model.pdf_outline import PdfOutline
from pdf4me.model.pdf_resources import PdfResources
from pdf4me.model.pdf_rotate import PdfRotate
from pdf4me.model.pdf_validation import PdfValidation
from pdf4me.model.pdf_validation_event import PdfValidationEvent
from pdf4me.model.produce_documents import ProduceDocuments
from pdf4me.model.produce_documents_res import ProduceDocumentsRes
from pdf4me.model.produce_output import ProduceOutput
from pdf4me.model.protect import Protect
from pdf4me.model.protect_action import ProtectAction
from pdf4me.model.protect_res import ProtectRes
from pdf4me.model.rgb_set import RGBSet
from pdf4me.model.read_barcode_action import ReadBarcodeAction
from pdf4me.model.read_barcodes import ReadBarcodes
from pdf4me.model.read_barcodes_res import ReadBarcodesRes
from pdf4me.model.recognize_document import RecognizeDocument
from pdf4me.model.recognize_document_res import RecognizeDocumentRes
from pdf4me.model.rectangle import Rectangle
from pdf4me.model.repair import Repair
from pdf4me.model.repair_action import RepairAction
from pdf4me.model.repair_res import RepairRes
from pdf4me.model.rotate import Rotate
from pdf4me.model.rotate_action import RotateAction
from pdf4me.model.rotate_config import RotateConfig
from pdf4me.model.rotate_res import RotateRes
from pdf4me.model.run_job_res import RunJobRes
from pdf4me.model.scan_barcode import ScanBarcode
from pdf4me.model.sign_action import SignAction
from pdf4me.model.sign_pdf import SignPdf
from pdf4me.model.sign_pdf_res import SignPdfRes
from pdf4me.model.signature_config import SignatureConfig
from pdf4me.model.signing_provider import SigningProvider
from pdf4me.model.split import Split
from pdf4me.model.split_action import SplitAction
from pdf4me.model.split_res import SplitRes
from pdf4me.model.stamp import Stamp
from pdf4me.model.stamp_action import StampAction
from pdf4me.model.stamp_res import StampRes
from pdf4me.model.storage_folder import StorageFolder
from pdf4me.model.text import Text
from pdf4me.model.transform import Transform
from pdf4me.model.translate import Translate
from pdf4me.model.usage_application import UsageApplication
from pdf4me.model.usage_application_req import UsageApplicationReq
from pdf4me.model.usage_application_res import UsageApplicationRes
from pdf4me.model.usage_subscription import UsageSubscription
from pdf4me.model.usage_subscription_req import UsageSubscriptionReq
from pdf4me.model.usage_subscription_res import UsageSubscriptionRes
from pdf4me.model.validate import Validate
from pdf4me.model.validate_action import ValidateAction
from pdf4me.model.validate_res import ValidateRes
from pdf4me.model.value_type import ValueType
from pdf4me.model.version_res import VersionRes



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.integration_setting import IntegrationSetting  # noqa: F401,E501
from pdf4me.model.notification import Notification  # noqa: F401,E501
from pdf4me.model.pdf4me_document import Pdf4meDocument  # noqa: F401,E501


class DropDocumentReq(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'notification': 'Notification',
        'job_id': 'str',
        'document_id': 'str',
        'user_id': 'str',
        'url': 'str',
        'document': 'str',
        'file_name': 'str',
        'cloud_storage_provider': 'str',
        'cloud_storage_files': 'list[str]',
        'cloud_storage_files_desc': 'str',
        'trace_id': 'str',
        'request_id': 'str',
        'integration_setting': 'IntegrationSetting',
        'job_id_ext': 'str',
        'documents': 'list[Pdf4meDocument]'
    }

    attribute_map = {
        'notification': 'notification',
        'job_id': 'jobId',
        'document_id': 'documentId',
        'user_id': 'userId',
        'url': 'url',
        'document': 'document',
        'file_name': 'fileName',
        'cloud_storage_provider': 'cloudStorageProvider',
        'cloud_storage_files': 'cloudStorageFiles',
        'cloud_storage_files_desc': 'cloudStorageFilesDesc',
        'trace_id': 'traceId',
        'request_id': 'requestId',
        'integration_setting': 'integrationSetting',
        'job_id_ext': 'jobIdExt',
        'documents': 'documents'
    }

    def __init__(self, notification=None, job_id=None, document_id=None, user_id=None, url=None, document=None, file_name=None, cloud_storage_provider=None, cloud_storage_files=None, cloud_storage_files_desc=None, trace_id=None, request_id=None, integration_setting=None, job_id_ext=None, documents=None):  # noqa: E501
        """DropDocumentReq - a model defined in Swagger"""  # noqa: E501

        self._notification = None
        self._job_id = None
        self._document_id = None
        self._user_id = None
        self._url = None
        self._document = None
        self._file_name = None
        self._cloud_storage_provider = None
        self._cloud_storage_files = None
        self._cloud_storage_files_desc = None
        self._trace_id = None
        self._request_id = None
        self._integration_setting = None
        self._job_id_ext = None
        self._documents = None
        self.discriminator = None

        if notification is not None:
            self.notification = notification
        if job_id is not None:
            self.job_id = job_id
        if document_id is not None:
            self.document_id = document_id
        if user_id is not None:
            self.user_id = user_id
        if url is not None:
            self.url = url
        if document is not None:
            self.document = document
        if file_name is not None:
            self.file_name = file_name
        if cloud_storage_provider is not None:
            self.cloud_storage_provider = cloud_storage_provider
        if cloud_storage_files is not None:
            self.cloud_storage_files = cloud_storage_files
        if cloud_storage_files_desc is not None:
            self.cloud_storage_files_desc = cloud_storage_files_desc
        if trace_id is not None:
            self.trace_id = trace_id
        if request_id is not None:
            self.request_id = request_id
        if integration_setting is not None:
            self.integration_setting = integration_setting
        if job_id_ext is not None:
            self.job_id_ext = job_id_ext
        if documents is not None:
            self.documents = documents

    @property
    def notification(self):
        """Gets the notification of this DropDocumentReq.  # noqa: E501


        :return: The notification of this DropDocumentReq.  # noqa: E501
        :rtype: Notification
        """
        return self._notification

    @notification.setter
    def notification(self, notification):
        """Sets the notification of this DropDocumentReq.


        :param notification: The notification of this DropDocumentReq.  # noqa: E501
        :type: Notification
        """

        self._notification = notification

    @property
    def job_id(self):
        """Gets the job_id of this DropDocumentReq.  # noqa: E501


        :return: The job_id of this DropDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this DropDocumentReq.


        :param job_id: The job_id of this DropDocumentReq.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def document_id(self):
        """Gets the document_id of this DropDocumentReq.  # noqa: E501


        :return: The document_id of this DropDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this DropDocumentReq.


        :param document_id: The document_id of this DropDocumentReq.  # noqa: E501
        :type: str
        """

        self._document_id = document_id

    @property
    def user_id(self):
        """Gets the user_id of this DropDocumentReq.  # noqa: E501


        :return: The user_id of this DropDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this DropDocumentReq.


        :param user_id: The user_id of this DropDocumentReq.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def url(self):
        """Gets the url of this DropDocumentReq.  # noqa: E501


        :return: The url of this DropDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this DropDocumentReq.


        :param url: The url of this DropDocumentReq.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def document(self):
        """Gets the document of this DropDocumentReq.  # noqa: E501


        :return: The document of this DropDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._document

    @document.setter
    def document(self, document):
        """Sets the document of this DropDocumentReq.


        :param document: The document of this DropDocumentReq.  # noqa: E501
        :type: str
        """
        if document is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', document):  # noqa: E501
            raise ValueError(r"Invalid value for `document`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._document = document

    @property
    def file_name(self):
        """Gets the file_name of this DropDocumentReq.  # noqa: E501


        :return: The file_name of this DropDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this DropDocumentReq.


        :param file_name: The file_name of this DropDocumentReq.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def cloud_storage_provider(self):
        """Gets the cloud_storage_provider of this DropDocumentReq.  # noqa: E501


        :return: The cloud_storage_provider of this DropDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._cloud_storage_provider

    @cloud_storage_provider.setter
    def cloud_storage_provider(self, cloud_storage_provider):
        """Sets the cloud_storage_provider of this DropDocumentReq.


        :param cloud_storage_provider: The cloud_storage_provider of this DropDocumentReq.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "local", "url", "oneDrive", "dropbox", "googleDrive", "kloudless"]  # noqa: E501
        if cloud_storage_provider not in allowed_values:
            raise ValueError(
                "Invalid value for `cloud_storage_provider` ({0}), must be one of {1}"  # noqa: E501
                .format(cloud_storage_provider, allowed_values)
            )

        self._cloud_storage_provider = cloud_storage_provider

    @property
    def cloud_storage_files(self):
        """Gets the cloud_storage_files of this DropDocumentReq.  # noqa: E501


        :return: The cloud_storage_files of this DropDocumentReq.  # noqa: E501
        :rtype: list[str]
        """
        return self._cloud_storage_files

    @cloud_storage_files.setter
    def cloud_storage_files(self, cloud_storage_files):
        """Sets the cloud_storage_files of this DropDocumentReq.


        :param cloud_storage_files: The cloud_storage_files of this DropDocumentReq.  # noqa: E501
        :type: list[str]
        """

        self._cloud_storage_files = cloud_storage_files

    @property
    def cloud_storage_files_desc(self):
        """Gets the cloud_storage_files_desc of this DropDocumentReq.  # noqa: E501


        :return: The cloud_storage_files_desc of this DropDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._cloud_storage_files_desc

    @cloud_storage_files_desc.setter
    def cloud_storage_files_desc(self, cloud_storage_files_desc):
        """Sets the cloud_storage_files_desc of this DropDocumentReq.


        :param cloud_storage_files_desc: The cloud_storage_files_desc of this DropDocumentReq.  # noqa: E501
        :type: str
        """

        self._cloud_storage_files_desc = cloud_storage_files_desc

    @property
    def trace_id(self):
        """Gets the trace_id of this DropDocumentReq.  # noqa: E501


        :return: The trace_id of this DropDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """Sets the trace_id of this DropDocumentReq.


        :param trace_id: The trace_id of this DropDocumentReq.  # noqa: E501
        :type: str
        """

        self._trace_id = trace_id

    @property
    def request_id(self):
        """Gets the request_id of this DropDocumentReq.  # noqa: E501


        :return: The request_id of this DropDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this DropDocumentReq.


        :param request_id: The request_id of this DropDocumentReq.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def integration_setting(self):
        """Gets the integration_setting of this DropDocumentReq.  # noqa: E501


        :return: The integration_setting of this DropDocumentReq.  # noqa: E501
        :rtype: IntegrationSetting
        """
        return self._integration_setting

    @integration_setting.setter
    def integration_setting(self, integration_setting):
        """Sets the integration_setting of this DropDocumentReq.


        :param integration_setting: The integration_setting of this DropDocumentReq.  # noqa: E501
        :type: IntegrationSetting
        """

        self._integration_setting = integration_setting

    @property
    def job_id_ext(self):
        """Gets the job_id_ext of this DropDocumentReq.  # noqa: E501


        :return: The job_id_ext of this DropDocumentReq.  # noqa: E501
        :rtype: str
        """
        return self._job_id_ext

    @job_id_ext.setter
    def job_id_ext(self, job_id_ext):
        """Sets the job_id_ext of this DropDocumentReq.


        :param job_id_ext: The job_id_ext of this DropDocumentReq.  # noqa: E501
        :type: str
        """

        self._job_id_ext = job_id_ext

    @property
    def documents(self):
        """Gets the documents of this DropDocumentReq.  # noqa: E501


        :return: The documents of this DropDocumentReq.  # noqa: E501
        :rtype: list[Pdf4meDocument]
        """
        return self._documents

    @documents.setter
    def documents(self, documents):
        """Sets the documents of this DropDocumentReq.


        :param documents: The documents of this DropDocumentReq.  # noqa: E501
        :type: list[Pdf4meDocument]
        """

        self._documents = documents

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DropDocumentReq, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DropDocumentReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PdfRotate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'page_nr': 'int',
        'rotation_type': 'str'
    }

    attribute_map = {
        'page_nr': 'pageNr',
        'rotation_type': 'rotationType'
    }

    def __init__(self, page_nr=None, rotation_type=None):  # noqa: E501
        """PdfRotate - a model defined in Swagger"""  # noqa: E501

        self._page_nr = None
        self._rotation_type = None
        self.discriminator = None

        if page_nr is not None:
            self.page_nr = page_nr
        if rotation_type is not None:
            self.rotation_type = rotation_type

    @property
    def page_nr(self):
        """Gets the page_nr of this PdfRotate.  # noqa: E501


        :return: The page_nr of this PdfRotate.  # noqa: E501
        :rtype: int
        """
        return self._page_nr

    @page_nr.setter
    def page_nr(self, page_nr):
        """Sets the page_nr of this PdfRotate.


        :param page_nr: The page_nr of this PdfRotate.  # noqa: E501
        :type: int
        """

        self._page_nr = page_nr

    @property
    def rotation_type(self):
        """Gets the rotation_type of this PdfRotate.  # noqa: E501


        :return: The rotation_type of this PdfRotate.  # noqa: E501
        :rtype: str
        """
        return self._rotation_type

    @rotation_type.setter
    def rotation_type(self, rotation_type):
        """Sets the rotation_type of this PdfRotate.


        :param rotation_type: The rotation_type of this PdfRotate.  # noqa: E501
        :type: str
        """
        allowed_values = ["noRotation", "clockwise", "counterClockwise", "upsideDown"]  # noqa: E501
        if rotation_type not in allowed_values:
            raise ValueError(
                "Invalid value for `rotation_type` ({0}), must be one of {1}"  # noqa: E501
                .format(rotation_type, allowed_values)
            )

        self._rotation_type = rotation_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PdfRotate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfRotate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    DmsApi

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ApiUsageRes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'api_usage': 'int',
        'payed_usage': 'int',
        'last_payment': 'datetime',
        'payment_profile': 'str'
    }

    attribute_map = {
        'api_usage': 'apiUsage',
        'payed_usage': 'payedUsage',
        'last_payment': 'lastPayment',
        'payment_profile': 'paymentProfile'
    }

    def __init__(self, api_usage=None, payed_usage=None, last_payment=None, payment_profile=None):  # noqa: E501
        """ApiUsageRes - a model defined in Swagger"""  # noqa: E501

        self._api_usage = None
        self._payed_usage = None
        self._last_payment = None
        self._payment_profile = None
        self.discriminator = None

        if api_usage is not None:
            self.api_usage = api_usage
        if payed_usage is not None:
            self.payed_usage = payed_usage
        if last_payment is not None:
            self.last_payment = last_payment
        if payment_profile is not None:
            self.payment_profile = payment_profile

    @property
    def api_usage(self):
        """Gets the api_usage of this ApiUsageRes.  # noqa: E501

        Api usage since last payment.  # noqa: E501

        :return: The api_usage of this ApiUsageRes.  # noqa: E501
        :rtype: int
        """
        return self._api_usage

    @api_usage.setter
    def api_usage(self, api_usage):
        """Sets the api_usage of this ApiUsageRes.

        Api usage since last payment.  # noqa: E501

        :param api_usage: The api_usage of this ApiUsageRes.  # noqa: E501
        :type: int
        """

        self._api_usage = api_usage

    @property
    def payed_usage(self):
        """Gets the payed_usage of this ApiUsageRes.  # noqa: E501

        Total Usage payed.  # noqa: E501

        :return: The payed_usage of this ApiUsageRes.  # noqa: E501
        :rtype: int
        """
        return self._payed_usage

    @payed_usage.setter
    def payed_usage(self, payed_usage):
        """Sets the payed_usage of this ApiUsageRes.

        Total Usage payed.  # noqa: E501

        :param payed_usage: The payed_usage of this ApiUsageRes.  # noqa: E501
        :type: int
        """

        self._payed_usage = payed_usage

    @property
    def last_payment(self):
        """Gets the last_payment of this ApiUsageRes.  # noqa: E501

        Date of last payment  # noqa: E501

        :return: The last_payment of this ApiUsageRes.  # noqa: E501
        :rtype: datetime
        """
        return self._last_payment

    @last_payment.setter
    def last_payment(self, last_payment):
        """Sets the last_payment of this ApiUsageRes.

        Date of last payment  # noqa: E501

        :param last_payment: The last_payment of this ApiUsageRes.  # noqa: E501
        :type: datetime
        """

        self._last_payment = last_payment

    @property
    def payment_profile(self):
        """Gets the payment_profile of this ApiUsageRes.  # noqa: E501

        Profile of selected payment  # noqa: E501

        :return: The payment_profile of this ApiUsageRes.  # noqa: E501
        :rtype: str
        """
        return self._payment_profile

    @payment_profile.setter
    def payment_profile(self, payment_profile):
        """Sets the payment_profile of this ApiUsageRes.

        Profile of selected payment  # noqa: E501

        :param payment_profile: The payment_profile of this ApiUsageRes.  # noqa: E501
        :type: str
        """

        self._payment_profile = payment_profile

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiUsageRes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.pdf_font import PdfFont  # noqa: F401,E501


class PdfAAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fonts_to_subset': 'list[PdfFont]',
        'compliance': 'str',
        'allow_downgrade': 'bool',
        'allow_upgrade': 'bool',
        'output_intent_profile': 'str',
        'linearize': 'bool'
    }

    attribute_map = {
        'fonts_to_subset': 'fontsToSubset',
        'compliance': 'compliance',
        'allow_downgrade': 'allowDowngrade',
        'allow_upgrade': 'allowUpgrade',
        'output_intent_profile': 'outputIntentProfile',
        'linearize': 'linearize'
    }

    def __init__(self, fonts_to_subset=None, compliance=None, allow_downgrade=None, allow_upgrade=None, output_intent_profile=None, linearize=None):  # noqa: E501
        """PdfAAction - a model defined in Swagger"""  # noqa: E501

        self._fonts_to_subset = None
        self._compliance = None
        self._allow_downgrade = None
        self._allow_upgrade = None
        self._output_intent_profile = None
        self._linearize = None
        self.discriminator = None

        if fonts_to_subset is not None:
            self.fonts_to_subset = fonts_to_subset
        if compliance is not None:
            self.compliance = compliance
        if allow_downgrade is not None:
            self.allow_downgrade = allow_downgrade
        if allow_upgrade is not None:
            self.allow_upgrade = allow_upgrade
        if output_intent_profile is not None:
            self.output_intent_profile = output_intent_profile
        if linearize is not None:
            self.linearize = linearize

    @property
    def fonts_to_subset(self):
        """Gets the fonts_to_subset of this PdfAAction.  # noqa: E501

        By default, fonts that are embedded are automatically subset to minimize the file size.   If for any reason, e.g. postprocessing, fonts shall not be subset, set the property   SubsetFonts to false. Whether fonts are subset or not is irrelevant with respect to   the compliance with PDF/A. (Relevant is only that all used glyphs are contained in the font program.)   Additionals Fonts can be given in this FontsToSubset List  # noqa: E501

        :return: The fonts_to_subset of this PdfAAction.  # noqa: E501
        :rtype: list[PdfFont]
        """
        return self._fonts_to_subset

    @fonts_to_subset.setter
    def fonts_to_subset(self, fonts_to_subset):
        """Sets the fonts_to_subset of this PdfAAction.

        By default, fonts that are embedded are automatically subset to minimize the file size.   If for any reason, e.g. postprocessing, fonts shall not be subset, set the property   SubsetFonts to false. Whether fonts are subset or not is irrelevant with respect to   the compliance with PDF/A. (Relevant is only that all used glyphs are contained in the font program.)   Additionals Fonts can be given in this FontsToSubset List  # noqa: E501

        :param fonts_to_subset: The fonts_to_subset of this PdfAAction.  # noqa: E501
        :type: list[PdfFont]
        """

        self._fonts_to_subset = fonts_to_subset

    @property
    def compliance(self):
        """Gets the compliance of this PdfAAction.  # noqa: E501

        Other listed entries (e.g. ePDF10, ePDF11, .. .ePDF17, ePDFUnk) are not supported as output compliance   level.  Some files cannot be converted to the compliance requested. This will be  detected and up- (AllowUpgrade) or downgrade (AllowDowngrade) the compliance automatically.  # noqa: E501

        :return: The compliance of this PdfAAction.  # noqa: E501
        :rtype: str
        """
        return self._compliance

    @compliance.setter
    def compliance(self, compliance):
        """Sets the compliance of this PdfAAction.

        Other listed entries (e.g. ePDF10, ePDF11, .. .ePDF17, ePDFUnk) are not supported as output compliance   level.  Some files cannot be converted to the compliance requested. This will be  detected and up- (AllowUpgrade) or downgrade (AllowDowngrade) the compliance automatically.  # noqa: E501

        :param compliance: The compliance of this PdfAAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["pdfA1b", "pdfA1a", "pdfA2b", "pdfA2u", "pdfA2a", "pdfA3b", "pdfA3u", "pdfA3a"]  # noqa: E501
        if compliance not in allowed_values:
            raise ValueError(
                "Invalid value for `compliance` ({0}), must be one of {1}"  # noqa: E501
                .format(compliance, allowed_values)
            )

        self._compliance = compliance

    @property
    def allow_downgrade(self):
        """Gets the allow_downgrade of this PdfAAction.  # noqa: E501

        If set to True, automatic downgrade of the PDF/A conformance level is allowed, e.g. from PDF/A-1a to PDF/A-1b.  If this property is set to True, the level is downgraded under the following conditions:    - Downgrade to level B: If a file contains text that is not extractable (i.e.missing ToUnicode information).  Example: Downgrade PDF/A-2u to PDF/A-2b.  - Downgrade to level U (PDF/A-2 and PDF/A-3) or B(PDF/A-1): Level A requires logical structure information and  “tagging” information, so if a file contains no such information, its level is downgraded.  <para>  Logical structure information in a PDF defines the structure of content, such as titles, paragraphs, figures, reading order, tables or articles.Logical structure elements can be “tagged” with descriptions or alternative text.  “Tagging” allows the contents of an image to be described to the visually impaired.  It is not possible for Pdf/A converter to add meaningful tagging information. Adding  tagging information without prior knowledge about the input file’s structure and content is neither possible nor  allowed by the PDF/A standard. For that reason, the conformance level is automatically downgraded to level B or U.  Example: Downgrade PDF/A-1a to PDF/A-1b.  </para><para>  If set to False and an input file cannot be converted to the requested standard, e.g.because of missing “tagging”  information, the conversion is aborted and the ErrorCode set to PDF_E_DOWNGRADE.  </para>  # noqa: E501

        :return: The allow_downgrade of this PdfAAction.  # noqa: E501
        :rtype: bool
        """
        return self._allow_downgrade

    @allow_downgrade.setter
    def allow_downgrade(self, allow_downgrade):
        """Sets the allow_downgrade of this PdfAAction.

        If set to True, automatic downgrade of the PDF/A conformance level is allowed, e.g. from PDF/A-1a to PDF/A-1b.  If this property is set to True, the level is downgraded under the following conditions:    - Downgrade to level B: If a file contains text that is not extractable (i.e.missing ToUnicode information).  Example: Downgrade PDF/A-2u to PDF/A-2b.  - Downgrade to level U (PDF/A-2 and PDF/A-3) or B(PDF/A-1): Level A requires logical structure information and  “tagging” information, so if a file contains no such information, its level is downgraded.  <para>  Logical structure information in a PDF defines the structure of content, such as titles, paragraphs, figures, reading order, tables or articles.Logical structure elements can be “tagged” with descriptions or alternative text.  “Tagging” allows the contents of an image to be described to the visually impaired.  It is not possible for Pdf/A converter to add meaningful tagging information. Adding  tagging information without prior knowledge about the input file’s structure and content is neither possible nor  allowed by the PDF/A standard. For that reason, the conformance level is automatically downgraded to level B or U.  Example: Downgrade PDF/A-1a to PDF/A-1b.  </para><para>  If set to False and an input file cannot be converted to the requested standard, e.g.because of missing “tagging”  information, the conversion is aborted and the ErrorCode set to PDF_E_DOWNGRADE.  </para>  # noqa: E501

        :param allow_downgrade: The allow_downgrade of this PdfAAction.  # noqa: E501
        :type: bool
        """

        self._allow_downgrade = allow_downgrade

    @property
    def allow_upgrade(self):
        """Gets the allow_upgrade of this PdfAAction.  # noqa: E501

         If set to True, automatic upgrade of the PDF/A version is allowed. If the target standard is PDF/A-1 and a file  contains elements that cannot be converted to PDF/A-1, the target standard is upgraded to PDF/A-2. This avoids  significant visual differences in the output file.  For example, the following elements may lead to an automatic upgrade:  - Transpanrecy  - Optional content groups(OCG, layers)  - Real values that exceed the implementation limit of PDF/A-1  - Embedded OpenType font files  - Predefined CMap encodings in Type0 fonts     If set to False, the compliance is not upgraded.Depeding on the value of the ConversionErrorMask the  conversion this will fail with a conversion error PDF_E_CONVERSION  # noqa: E501

        :return: The allow_upgrade of this PdfAAction.  # noqa: E501
        :rtype: bool
        """
        return self._allow_upgrade

    @allow_upgrade.setter
    def allow_upgrade(self, allow_upgrade):
        """Sets the allow_upgrade of this PdfAAction.

         If set to True, automatic upgrade of the PDF/A version is allowed. If the target standard is PDF/A-1 and a file  contains elements that cannot be converted to PDF/A-1, the target standard is upgraded to PDF/A-2. This avoids  significant visual differences in the output file.  For example, the following elements may lead to an automatic upgrade:  - Transpanrecy  - Optional content groups(OCG, layers)  - Real values that exceed the implementation limit of PDF/A-1  - Embedded OpenType font files  - Predefined CMap encodings in Type0 fonts     If set to False, the compliance is not upgraded.Depeding on the value of the ConversionErrorMask the  conversion this will fail with a conversion error PDF_E_CONVERSION  # noqa: E501

        :param allow_upgrade: The allow_upgrade of this PdfAAction.  # noqa: E501
        :type: bool
        """

        self._allow_upgrade = allow_upgrade

    @property
    def output_intent_profile(self):
        """Gets the output_intent_profile of this PdfAAction.  # noqa: E501

        <para>              Set or get the path to the ICC profile for the output intent.              </para>  <para>              The given profile is embedded only if the input file does not contain a PDF/A output intent already              </para>  # noqa: E501

        :return: The output_intent_profile of this PdfAAction.  # noqa: E501
        :rtype: str
        """
        return self._output_intent_profile

    @output_intent_profile.setter
    def output_intent_profile(self, output_intent_profile):
        """Sets the output_intent_profile of this PdfAAction.

        <para>              Set or get the path to the ICC profile for the output intent.              </para>  <para>              The given profile is embedded only if the input file does not contain a PDF/A output intent already              </para>  # noqa: E501

        :param output_intent_profile: The output_intent_profile of this PdfAAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["notSet", "sRGBColorSpace"]  # noqa: E501
        if output_intent_profile not in allowed_values:
            raise ValueError(
                "Invalid value for `output_intent_profile` ({0}), must be one of {1}"  # noqa: E501
                .format(output_intent_profile, allowed_values)
            )

        self._output_intent_profile = output_intent_profile

    @property
    def linearize(self):
        """Gets the linearize of this PdfAAction.  # noqa: E501

        <para>              Get or set whether to linearize the PDF output file, i.e. optimize file for fast web access.              A linearized document has a slightly larger file size than a non-linearized file and provides the following main features:              - When a document is opened in a PDF viewer of a web browser, the first page can be viewed without downloading the entire               PDF file.In contrast, a non-linearized PDF file must be downloaded completely before the firstpage can be displayed.              - When another page is requested by the user, that page is displayed as quickly as possible and incrementally as              data arrives, without downloading the entire PDF file.              </para>  <para>              Signed files cannot be linearizes.So this property must be set to False if              a digital signature is applied.              </para>  # noqa: E501

        :return: The linearize of this PdfAAction.  # noqa: E501
        :rtype: bool
        """
        return self._linearize

    @linearize.setter
    def linearize(self, linearize):
        """Sets the linearize of this PdfAAction.

        <para>              Get or set whether to linearize the PDF output file, i.e. optimize file for fast web access.              A linearized document has a slightly larger file size than a non-linearized file and provides the following main features:              - When a document is opened in a PDF viewer of a web browser, the first page can be viewed without downloading the entire               PDF file.In contrast, a non-linearized PDF file must be downloaded completely before the firstpage can be displayed.              - When another page is requested by the user, that page is displayed as quickly as possible and incrementally as              data arrives, without downloading the entire PDF file.              </para>  <para>              Signed files cannot be linearizes.So this property must be set to False if              a digital signature is applied.              </para>  # noqa: E501

        :param linearize: The linearize of this PdfAAction.  # noqa: E501
        :type: bool
        """

        self._linearize = linearize

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PdfAAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfAAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pdf4me.model.custom_cms_config import CustomCMSConfig  # noqa: F401,E501
from pdf4me.model.page_selection import PageSelection  # noqa: F401,E501


class ImageAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'page_selection': 'PageSelection',
        'center': 'bool',
        'fit_page': 'bool',
        'bits_per_pixel': 'int',
        'bilevel_threshold': 'int',
        'width_pixel': 'int',
        'height_pixel': 'int',
        'width_point': 'int',
        'height_point': 'int',
        'render_options': 'list[str]',
        'rotate_mode': 'str',
        'preserve_aspect_ratio': 'bool',
        'image_quality': 'int',
        'cms_engine': 'str',
        'custom_cms_config': 'CustomCMSConfig',
        'dithering': 'str',
        'dpi': 'int',
        'fill_order': 'str',
        'filter_ratio': 'int',
        'image_extension': 'str',
        'color_space': 'str',
        'compression': 'str'
    }

    attribute_map = {
        'page_selection': 'pageSelection',
        'center': 'center',
        'fit_page': 'fitPage',
        'bits_per_pixel': 'bitsPerPixel',
        'bilevel_threshold': 'bilevelThreshold',
        'width_pixel': 'widthPixel',
        'height_pixel': 'heightPixel',
        'width_point': 'widthPoint',
        'height_point': 'heightPoint',
        'render_options': 'renderOptions',
        'rotate_mode': 'rotateMode',
        'preserve_aspect_ratio': 'preserveAspectRatio',
        'image_quality': 'imageQuality',
        'cms_engine': 'cmsEngine',
        'custom_cms_config': 'customCMSConfig',
        'dithering': 'dithering',
        'dpi': 'dpi',
        'fill_order': 'fillOrder',
        'filter_ratio': 'filterRatio',
        'image_extension': 'imageExtension',
        'color_space': 'colorSpace',
        'compression': 'compression'
    }

    def __init__(self, page_selection=None, center=None, fit_page=None, bits_per_pixel=None, bilevel_threshold=None, width_pixel=None, height_pixel=None, width_point=None, height_point=None, render_options=None, rotate_mode=None, preserve_aspect_ratio=None, image_quality=None, cms_engine=None, custom_cms_config=None, dithering=None, dpi=None, fill_order=None, filter_ratio=None, image_extension=None, color_space=None, compression=None):  # noqa: E501
        """ImageAction - a model defined in Swagger"""  # noqa: E501

        self._page_selection = None
        self._center = None
        self._fit_page = None
        self._bits_per_pixel = None
        self._bilevel_threshold = None
        self._width_pixel = None
        self._height_pixel = None
        self._width_point = None
        self._height_point = None
        self._render_options = None
        self._rotate_mode = None
        self._preserve_aspect_ratio = None
        self._image_quality = None
        self._cms_engine = None
        self._custom_cms_config = None
        self._dithering = None
        self._dpi = None
        self._fill_order = None
        self._filter_ratio = None
        self._image_extension = None
        self._color_space = None
        self._compression = None
        self.discriminator = None

        self.page_selection = page_selection
        if center is not None:
            self.center = center
        if fit_page is not None:
            self.fit_page = fit_page
        if bits_per_pixel is not None:
            self.bits_per_pixel = bits_per_pixel
        if bilevel_threshold is not None:
            self.bilevel_threshold = bilevel_threshold
        if width_pixel is not None:
            self.width_pixel = width_pixel
        if height_pixel is not None:
            self.height_pixel = height_pixel
        if width_point is not None:
            self.width_point = width_point
        if height_point is not None:
            self.height_point = height_point
        if render_options is not None:
            self.render_options = render_options
        if rotate_mode is not None:
            self.rotate_mode = rotate_mode
        if preserve_aspect_ratio is not None:
            self.preserve_aspect_ratio = preserve_aspect_ratio
        if image_quality is not None:
            self.image_quality = image_quality
        if cms_engine is not None:
            self.cms_engine = cms_engine
        if custom_cms_config is not None:
            self.custom_cms_config = custom_cms_config
        if dithering is not None:
            self.dithering = dithering
        if dpi is not None:
            self.dpi = dpi
        if fill_order is not None:
            self.fill_order = fill_order
        if filter_ratio is not None:
            self.filter_ratio = filter_ratio
        if image_extension is not None:
            self.image_extension = image_extension
        if color_space is not None:
            self.color_space = color_space
        if compression is not None:
            self.compression = compression

    @property
    def page_selection(self):
        """Gets the page_selection of this ImageAction.  # noqa: E501

        Set the Pages wo apply the convertion.    {default: PageSelection.All}  # noqa: E501

        :return: The page_selection of this ImageAction.  # noqa: E501
        :rtype: PageSelection
        """
        return self._page_selection

    @page_selection.setter
    def page_selection(self, page_selection):
        """Sets the page_selection of this ImageAction.

        Set the Pages wo apply the convertion.    {default: PageSelection.All}  # noqa: E501

        :param page_selection: The page_selection of this ImageAction.  # noqa: E501
        :type: PageSelection
        """
        # if page_selection is None:
        #     raise ValueError("Invalid value for `page_selection`, must not be `None`")  # noqa: E501

        self._page_selection = page_selection

    @property
    def center(self):
        """Gets the center of this ImageAction.  # noqa: E501

        Set or get the center mode. When set to True, the document is horizontally and vertically centered on the page.  When set to False, the document is printed to the upper left corner of the page.    {default: false}  # noqa: E501

        :return: The center of this ImageAction.  # noqa: E501
        :rtype: bool
        """
        return self._center

    @center.setter
    def center(self, center):
        """Sets the center of this ImageAction.

        Set or get the center mode. When set to True, the document is horizontally and vertically centered on the page.  When set to False, the document is printed to the upper left corner of the page.    {default: false}  # noqa: E501

        :param center: The center of this ImageAction.  # noqa: E501
        :type: bool
        """

        self._center = center

    @property
    def fit_page(self):
        """Gets the fit_page of this ImageAction.  # noqa: E501

        set the fit page mode. If set to True, the page is scaled to fit the image (in either width or height). If set to  False, the page is rendered with its true size.  {default: true}  # noqa: E501

        :return: The fit_page of this ImageAction.  # noqa: E501
        :rtype: bool
        """
        return self._fit_page

    @fit_page.setter
    def fit_page(self, fit_page):
        """Sets the fit_page of this ImageAction.

        set the fit page mode. If set to True, the page is scaled to fit the image (in either width or height). If set to  False, the page is rendered with its true size.  {default: true}  # noqa: E501

        :param fit_page: The fit_page of this ImageAction.  # noqa: E501
        :type: bool
        """

        self._fit_page = fit_page

    @property
    def bits_per_pixel(self):
        """Gets the bits_per_pixel of this ImageAction.  # noqa: E501

        Get or set the color depth. Bi-tonal: 1, gray scale: 8, RGB true color: 24, CMYK: 32.    {default: 24}  # noqa: E501

        :return: The bits_per_pixel of this ImageAction.  # noqa: E501
        :rtype: int
        """
        return self._bits_per_pixel

    @bits_per_pixel.setter
    def bits_per_pixel(self, bits_per_pixel):
        """Sets the bits_per_pixel of this ImageAction.

        Get or set the color depth. Bi-tonal: 1, gray scale: 8, RGB true color: 24, CMYK: 32.    {default: 24}  # noqa: E501

        :param bits_per_pixel: The bits_per_pixel of this ImageAction.  # noqa: E501
        :type: int
        """

        self._bits_per_pixel = bits_per_pixel

    @property
    def bilevel_threshold(self):
        """Gets the bilevel_threshold of this ImageAction.  # noqa: E501

        Set the threshold for converting from gray to bi-tonal when Dithering is eDitherNone. Value must be in  the range of 0 to 255.    {default: 181}  # noqa: E501

        :return: The bilevel_threshold of this ImageAction.  # noqa: E501
        :rtype: int
        """
        return self._bilevel_threshold

    @bilevel_threshold.setter
    def bilevel_threshold(self, bilevel_threshold):
        """Sets the bilevel_threshold of this ImageAction.

        Set the threshold for converting from gray to bi-tonal when Dithering is eDitherNone. Value must be in  the range of 0 to 255.    {default: 181}  # noqa: E501

        :param bilevel_threshold: The bilevel_threshold of this ImageAction.  # noqa: E501
        :type: int
        """

        self._bilevel_threshold = bilevel_threshold

    @property
    def width_pixel(self):
        """Gets the width_pixel of this ImageAction.  # noqa: E501


        :return: The width_pixel of this ImageAction.  # noqa: E501
        :rtype: int
        """
        return self._width_pixel

    @width_pixel.setter
    def width_pixel(self, width_pixel):
        """Sets the width_pixel of this ImageAction.


        :param width_pixel: The width_pixel of this ImageAction.  # noqa: E501
        :type: int
        """

        self._width_pixel = width_pixel

    @property
    def height_pixel(self):
        """Gets the height_pixel of this ImageAction.  # noqa: E501


        :return: The height_pixel of this ImageAction.  # noqa: E501
        :rtype: int
        """
        return self._height_pixel

    @height_pixel.setter
    def height_pixel(self, height_pixel):
        """Sets the height_pixel of this ImageAction.


        :param height_pixel: The height_pixel of this ImageAction.  # noqa: E501
        :type: int
        """

        self._height_pixel = height_pixel

    @property
    def width_point(self):
        """Gets the width_point of this ImageAction.  # noqa: E501


        :return: The width_point of this ImageAction.  # noqa: E501
        :rtype: int
        """
        return self._width_point

    @width_point.setter
    def width_point(self, width_point):
        """Sets the width_point of this ImageAction.


        :param width_point: The width_point of this ImageAction.  # noqa: E501
        :type: int
        """

        self._width_point = width_point

    @property
    def height_point(self):
        """Gets the height_point of this ImageAction.  # noqa: E501


        :return: The height_point of this ImageAction.  # noqa: E501
        :rtype: int
        """
        return self._height_point

    @height_point.setter
    def height_point(self, height_point):
        """Sets the height_point of this ImageAction.


        :param height_point: The height_point of this ImageAction.  # noqa: E501
        :type: int
        """

        self._height_point = height_point

    @property
    def render_options(self):
        """Gets the render_options of this ImageAction.  # noqa: E501

        Set a specific rendering option.  # noqa: E501

        :return: The render_options of this ImageAction.  # noqa: E501
        :rtype: list[str]
        """
        return self._render_options

    @render_options.setter
    def render_options(self, render_options):
        """Sets the render_options of this ImageAction.

        Set a specific rendering option.  # noqa: E501

        :param render_options: The render_options of this ImageAction.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["noAntialiasing", "noInterpolation", "noLowPassFilter", "noHinting", "printingMode", "noBPC", "fitPaths", "useBoxFilter"]  # noqa: E501
        if not set(render_options).issubset(set(allowed_values)):
            raise ValueError(
                "Invalid values for `render_options` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(render_options) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._render_options = render_options

    @property
    def rotate_mode(self):
        """Gets the rotate_mode of this ImageAction.  # noqa: E501

        Set the rotation mode of the page.    Attribute: Set the rotation to the viewing rotation attribute of the PDF page, i.e. rendering the  page with the same rotation as it is displayed in a PDF viewer.    {default: Attribute}  # noqa: E501

        :return: The rotate_mode of this ImageAction.  # noqa: E501
        :rtype: str
        """
        return self._rotate_mode

    @rotate_mode.setter
    def rotate_mode(self, rotate_mode):
        """Sets the rotate_mode of this ImageAction.

        Set the rotation mode of the page.    Attribute: Set the rotation to the viewing rotation attribute of the PDF page, i.e. rendering the  page with the same rotation as it is displayed in a PDF viewer.    {default: Attribute}  # noqa: E501

        :param rotate_mode: The rotate_mode of this ImageAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "attribute", "portrait", "landscape"]  # noqa: E501
        if rotate_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `rotate_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(rotate_mode, allowed_values)
            )

        self._rotate_mode = rotate_mode

    @property
    def preserve_aspect_ratio(self):
        """Gets the preserve_aspect_ratio of this ImageAction.  # noqa: E501

        If True a uniform up- or down-scaling is applied, i.e. the output image has the same ratio of width to height as the  input file and its size will fit into the defined dimensions, given by SetBitmapDimensions.    {default: true}  # noqa: E501

        :return: The preserve_aspect_ratio of this ImageAction.  # noqa: E501
        :rtype: bool
        """
        return self._preserve_aspect_ratio

    @preserve_aspect_ratio.setter
    def preserve_aspect_ratio(self, preserve_aspect_ratio):
        """Sets the preserve_aspect_ratio of this ImageAction.

        If True a uniform up- or down-scaling is applied, i.e. the output image has the same ratio of width to height as the  input file and its size will fit into the defined dimensions, given by SetBitmapDimensions.    {default: true}  # noqa: E501

        :param preserve_aspect_ratio: The preserve_aspect_ratio of this ImageAction.  # noqa: E501
        :type: bool
        """

        self._preserve_aspect_ratio = preserve_aspect_ratio

    @property
    def image_quality(self):
        """Gets the image_quality of this ImageAction.  # noqa: E501

        Set the quality index of lossy compression types. This value ranges from 1 to 100 and is applied to JPEG and  JPEG2000 compression.For JPEG2000, a quality index of 100 means lossless compression.JPEG compression is  always lossy.    {default: 80}  # noqa: E501

        :return: The image_quality of this ImageAction.  # noqa: E501
        :rtype: int
        """
        return self._image_quality

    @image_quality.setter
    def image_quality(self, image_quality):
        """Sets the image_quality of this ImageAction.

        Set the quality index of lossy compression types. This value ranges from 1 to 100 and is applied to JPEG and  JPEG2000 compression.For JPEG2000, a quality index of 100 means lossless compression.JPEG compression is  always lossy.    {default: 80}  # noqa: E501

        :param image_quality: The image_quality of this ImageAction.  # noqa: E501
        :type: int
        """

        self._image_quality = image_quality

    @property
    def cms_engine(self):
        """Gets the cms_engine of this ImageAction.  # noqa: E501

        Set the Color Management System (CMS) Engine.     {default: 80}  # noqa: E501

        :return: The cms_engine of this ImageAction.  # noqa: E501
        :rtype: str
        """
        return self._cms_engine

    @cms_engine.setter
    def cms_engine(self, cms_engine):
        """Sets the cms_engine of this ImageAction.

        Set the Color Management System (CMS) Engine.     {default: 80}  # noqa: E501

        :param cms_engine: The cms_engine of this ImageAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "neugebauer", "lcms", "customCMSConfig"]  # noqa: E501
        if cms_engine not in allowed_values:
            raise ValueError(
                "Invalid value for `cms_engine` ({0}), must be one of {1}"  # noqa: E501
                .format(cms_engine, allowed_values)
            )

        self._cms_engine = cms_engine

    @property
    def custom_cms_config(self):
        """Gets the custom_cms_config of this ImageAction.  # noqa: E501

        Set the Color Management System (CMS) Engine.     {default: 80}  # noqa: E501

        :return: The custom_cms_config of this ImageAction.  # noqa: E501
        :rtype: CustomCMSConfig
        """
        return self._custom_cms_config

    @custom_cms_config.setter
    def custom_cms_config(self, custom_cms_config):
        """Sets the custom_cms_config of this ImageAction.

        Set the Color Management System (CMS) Engine.     {default: 80}  # noqa: E501

        :param custom_cms_config: The custom_cms_config of this ImageAction.  # noqa: E501
        :type: CustomCMSConfig
        """

        self._custom_cms_config = custom_cms_config

    @property
    def dithering(self):
        """Gets the dithering of this ImageAction.  # noqa: E501

        Set the dithering algorithm.Dithering refers to the procedure of simulating colors or grayscales.This is mainly  useful for low color depth (e.g.black and white or indexed) images.  The supported values for TPDFDithering are listed in the corresponding enumeration.  {default: DitherFloydSteinberg}  # noqa: E501

        :return: The dithering of this ImageAction.  # noqa: E501
        :rtype: str
        """
        return self._dithering

    @dithering.setter
    def dithering(self, dithering):
        """Sets the dithering of this ImageAction.

        Set the dithering algorithm.Dithering refers to the procedure of simulating colors or grayscales.This is mainly  useful for low color depth (e.g.black and white or indexed) images.  The supported values for TPDFDithering are listed in the corresponding enumeration.  {default: DitherFloydSteinberg}  # noqa: E501

        :param dithering: The dithering of this ImageAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "floydSteinberg", "halftone", "pattern", "g3Optimized", "g4Optimized", "atkinson"]  # noqa: E501
        if dithering not in allowed_values:
            raise ValueError(
                "Invalid value for `dithering` ({0}), must be one of {1}"  # noqa: E501
                .format(dithering, allowed_values)
            )

        self._dithering = dithering

    @property
    def dpi(self):
        """Gets the dpi of this ImageAction.  # noqa: E501

        <p>              Get or set the resolution of the image in DPI (dots per inch).              Set Both the resolutions for the x- and y-axis are set to the same value.              </p>  <p>              Setting DPI is redundant to setting the specialized properties XDPI and YDPI.              </p>  {default: 150}  # noqa: E501

        :return: The dpi of this ImageAction.  # noqa: E501
        :rtype: int
        """
        return self._dpi

    @dpi.setter
    def dpi(self, dpi):
        """Sets the dpi of this ImageAction.

        <p>              Get or set the resolution of the image in DPI (dots per inch).              Set Both the resolutions for the x- and y-axis are set to the same value.              </p>  <p>              Setting DPI is redundant to setting the specialized properties XDPI and YDPI.              </p>  {default: 150}  # noqa: E501

        :param dpi: The dpi of this ImageAction.  # noqa: E501
        :type: int
        """

        self._dpi = dpi

    @property
    def fill_order(self):
        """Gets the fill_order of this ImageAction.  # noqa: E501

        Set the bit fill order.  MSB (Most significant bit) or LSB (Least significant bit) first.    {default: MostSignificantBit}  # noqa: E501

        :return: The fill_order of this ImageAction.  # noqa: E501
        :rtype: str
        """
        return self._fill_order

    @fill_order.setter
    def fill_order(self, fill_order):
        """Sets the fill_order of this ImageAction.

        Set the bit fill order.  MSB (Most significant bit) or LSB (Least significant bit) first.    {default: MostSignificantBit}  # noqa: E501

        :param fill_order: The fill_order of this ImageAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["mostSignificantBit", "leastSignificantBit"]  # noqa: E501
        if fill_order not in allowed_values:
            raise ValueError(
                "Invalid value for `fill_order` ({0}), must be one of {1}"  # noqa: E501
                .format(fill_order, allowed_values)
            )

        self._fill_order = fill_order

    @property
    def filter_ratio(self):
        """Gets the filter_ratio of this ImageAction.  # noqa: E501

        <p>              This property is used to enable and parameterize super-sampling, a technique to initially render the image at a              higher resolution and then sample it down to the target resolution.As a result of that process the final image              appears smoother, i.e.anti-aliased.              </p>  <p>              Applying super-sampling improves the image quality when rendering at low target resolutions(72 DPI or less); the              higher the target resolution the less the visual impact.              This property requires memory and CPU time quadratically to the ratio, therefore only small values, such as 2 or 3              should be used.              </p>  <p>              If a too high value (in combination with the original image size) is set, it is ignored.              </p>  {default: 1}  # noqa: E501

        :return: The filter_ratio of this ImageAction.  # noqa: E501
        :rtype: int
        """
        return self._filter_ratio

    @filter_ratio.setter
    def filter_ratio(self, filter_ratio):
        """Sets the filter_ratio of this ImageAction.

        <p>              This property is used to enable and parameterize super-sampling, a technique to initially render the image at a              higher resolution and then sample it down to the target resolution.As a result of that process the final image              appears smoother, i.e.anti-aliased.              </p>  <p>              Applying super-sampling improves the image quality when rendering at low target resolutions(72 DPI or less); the              higher the target resolution the less the visual impact.              This property requires memory and CPU time quadratically to the ratio, therefore only small values, such as 2 or 3              should be used.              </p>  <p>              If a too high value (in combination with the original image size) is set, it is ignored.              </p>  {default: 1}  # noqa: E501

        :param filter_ratio: The filter_ratio of this ImageAction.  # noqa: E501
        :type: int
        """

        self._filter_ratio = filter_ratio

    @property
    def image_extension(self):
        """Gets the image_extension of this ImageAction.  # noqa: E501

        Set output Type for image file.  # noqa: E501

        :return: The image_extension of this ImageAction.  # noqa: E501
        :rtype: str
        """
        return self._image_extension

    @image_extension.setter
    def image_extension(self, image_extension):
        """Sets the image_extension of this ImageAction.

        Set output Type for image file.  # noqa: E501

        :param image_extension: The image_extension of this ImageAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["jpg", "jpeg", "bmp", "gif", "jb2", "jp2", "jpf", "jpx", "png", "tif", "tiff"]  # noqa: E501
        if image_extension not in allowed_values:
            raise ValueError(
                "Invalid value for `image_extension` ({0}), must be one of {1}"  # noqa: E501
                .format(image_extension, allowed_values)
            )

        self._image_extension = image_extension

    @property
    def color_space(self):
        """Gets the color_space of this ImageAction.  # noqa: E501

        Set color space of the output image, see enumeration TPDFColorSpace.  For black white bi-tonal images, a gray color space must be selected    {default: ColorRGB}  # noqa: E501

        :return: The color_space of this ImageAction.  # noqa: E501
        :rtype: str
        """
        return self._color_space

    @color_space.setter
    def color_space(self, color_space):
        """Sets the color_space of this ImageAction.

        Set color space of the output image, see enumeration TPDFColorSpace.  For black white bi-tonal images, a gray color space must be selected    {default: ColorRGB}  # noqa: E501

        :param color_space: The color_space of this ImageAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["rGB", "rGBA", "gray", "grayA", "cMYK", "yCbCr", "yCbCrK", "palette", "lAB", "cMYK_Konly", "cMYKA"]  # noqa: E501
        if color_space not in allowed_values:
            raise ValueError(
                "Invalid value for `color_space` ({0}), must be one of {1}"  # noqa: E501
                .format(color_space, allowed_values)
            )

        self._color_space = color_space

    @property
    def compression(self):
        """Gets the compression of this ImageAction.  # noqa: E501

        Get or set the compression type of TIFF images. For any other image format, the compression is automatically  defined by the file extension(the file name).  The supported values for TPDFCompression are listed in the corresponding enumeration.                {default: ComprLZW}  # noqa: E501

        :return: The compression of this ImageAction.  # noqa: E501
        :rtype: str
        """
        return self._compression

    @compression.setter
    def compression(self, compression):
        """Sets the compression of this ImageAction.

        Get or set the compression type of TIFF images. For any other image format, the compression is automatically  defined by the file extension(the file name).  The supported values for TPDFCompression are listed in the corresponding enumeration.                {default: ComprLZW}  # noqa: E501

        :param compression: The compression of this ImageAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["lZW", "jPEG", "flate", "raw", "group3", "group3_2D", "group4", "jBIG2", "jPEG2000", "tIFFJPEG"]  # noqa: E501
        if compression not in allowed_values:
            raise ValueError(
                "Invalid value for `compression` ({0}), must be one of {1}"  # noqa: E501
                .format(compression, allowed_values)
            )

        self._compression = compression

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ImageAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImageAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# import base64
# import json
# import time

# import adal
# from msrestazure.azure_active_directory import AADTokenCredentials

# TENANT = "devynooxlive.onmicrosoft.com"
# AUTHORITY_URI = "https://login.microsoftonline.com/" + TENANT

# # slack: time before expiration, when already a new token is acquired
# SLACK = 60  # 1min


# class TokenGenerator(object):

#     def __init__(self, client_id, secret):

#         self.client_id = client_id
#         self.resource_uri = self.client_id
#         self.secret = secret
#         self.token = None

#     def get_token(self):
#         '''
#         Loads or aquires the authorization token.
#         :return: token string
#         '''
#         if self.__valid_token() is True:
#             return self.token
#         else:
#             return self.__get_new_token()

#     def __valid_token(self):
#         '''
#         Checks whether the stored token has not expired yet.
#         :return: whether the stored token is still valid
#         '''

#         if self.token is None:
#             return False

#         timestamp = self.token.split('.')[1]
#         # correct padding
#         timestamp = timestamp + '=' * (-len(timestamp) % 4)
#         # json format
#         json_bytes = base64.b64decode(timestamp)
#         # extract expiration time [sec]
#         json_string = json_bytes.decode("utf-8")
#         json_object = json.loads(json_string)
#         expiration = json_object["exp"]

#         # current time
#         now = time.time()

#         # check
#         if now < expiration - SLACK:
#             return True
#         else:
#             return False

#     def __get_new_token(self):
#         '''
#         Acquires a new token using the clientID and secret.
#         :return: newly generated token
#         '''

#         # generate token
#         context = adal.AuthenticationContext(AUTHORITY_URI, api_version=None)
#         mgmt_token = context.acquire_token_with_client_credentials(self.resource_uri, self.client_id, self.secret)
#         credentials = AADTokenCredentials(mgmt_token, self.client_id)
#         token = credentials.token["access_token"]

#         # store new token
#         self.token = token

#         return self.token
